# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/state/execution_state_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.execution.v1.state import execution_state_pb2 as qwak_dot_execution_dot_v1_dot_state_dot_execution__state__pb2
from _qwak_proto.qwak.execution.v1.state import featureset_state_pb2 as qwak_dot_execution_dot_v1_dot_state_dot_featureset__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5qwak/execution/v1/state/execution_state_service.proto\x12%qwak.feature.store.execution.v1.state\x1a-qwak/execution/v1/state/execution_state.proto\x1a.qwak/execution/v1/state/featureset_state.proto\"6\n\x1dGetFeaturesetStateByIdRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\"r\n\x1eGetFeaturesetStateByIdResponse\x12P\n\x10\x66\x65\x61tureset_state\x18\x01 \x01(\x0b\x32\x36.qwak.feature.store.execution.v1.state.FeaturesetState\":\n\x1fGetFeaturesetStateByNameRequest\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\"t\n GetFeaturesetStateByNameResponse\x12P\n\x10\x66\x65\x61tureset_state\x18\x01 \x01(\x0b\x32\x36.qwak.feature.store.execution.v1.state.FeaturesetState\"=\n#GetMultiFeaturesetStateByIdsRequest\x12\x16\n\x0e\x66\x65\x61tureset_ids\x18\x01 \x03(\t\"y\n$GetMultiFeaturesetStateByIdsResponse\x12Q\n\x11\x66\x65\x61tureset_states\x18\x01 \x03(\x0b\x32\x36.qwak.feature.store.execution.v1.state.FeaturesetState\"?\n$GetMultiFeaturesetStateByNameRequest\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x03(\t\"y\n%GetMultiFeaturesetStateByNameResponse\x12P\n\x10\x66\x65\x61tureset_state\x18\x01 \x03(\x0b\x32\x36.qwak.feature.store.execution.v1.state.FeaturesetState\"r\n UpdateMultiExecutionStateRequest\x12N\n\x0f\x65xecution_state\x18\x01 \x03(\x0b\x32\x35.qwak.feature.store.execution.v1.state.ExecutionState\"#\n!UpdateMultiExecutionStateResponse\"9\n DeleteFeaturesetStateByIdRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\"@\n!DeleteFeaturesetStateByIdResponse\x12\x1b\n\x13num_deleted_records\x18\x01 \x01(\x03\x32\xd2\x08\n!FeatureStoreExecutionStateService\x12\xa5\x01\n\x16GetFeaturesetStateById\x12\x44.qwak.feature.store.execution.v1.state.GetFeaturesetStateByIdRequest\x1a\x45.qwak.feature.store.execution.v1.state.GetFeaturesetStateByIdResponse\x12\xab\x01\n\x18GetFeaturesetStateByName\x12\x46.qwak.feature.store.execution.v1.state.GetFeaturesetStateByNameRequest\x1aG.qwak.feature.store.execution.v1.state.GetFeaturesetStateByNameResponse\x12\xb7\x01\n\x1cGetMultiFeaturesetStateByIds\x12J.qwak.feature.store.execution.v1.state.GetMultiFeaturesetStateByIdsRequest\x1aK.qwak.feature.store.execution.v1.state.GetMultiFeaturesetStateByIdsResponse\x12\xba\x01\n\x1dGetMultiFeaturesetStateByName\x12K.qwak.feature.store.execution.v1.state.GetMultiFeaturesetStateByNameRequest\x1aL.qwak.feature.store.execution.v1.state.GetMultiFeaturesetStateByNameResponse\x12\xae\x01\n\x19UpdateMultiExecutionState\x12G.qwak.feature.store.execution.v1.state.UpdateMultiExecutionStateRequest\x1aH.qwak.feature.store.execution.v1.state.UpdateMultiExecutionStateResponse\x12\xae\x01\n\x19\x44\x65leteFeaturesetStateById\x12G.qwak.feature.store.execution.v1.state.DeleteFeaturesetStateByIdRequest\x1aH.qwak.feature.store.execution.v1.state.DeleteFeaturesetStateByIdResponseB`\n+com.qwak.ai.features.execution.api.v1.stateP\x01Z/qwak/execution_management/state;execution_stateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.execution.v1.state.execution_state_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n+com.qwak.ai.features.execution.api.v1.stateP\001Z/qwak/execution_management/state;execution_state'
  _globals['_GETFEATURESETSTATEBYIDREQUEST']._serialized_start=191
  _globals['_GETFEATURESETSTATEBYIDREQUEST']._serialized_end=245
  _globals['_GETFEATURESETSTATEBYIDRESPONSE']._serialized_start=247
  _globals['_GETFEATURESETSTATEBYIDRESPONSE']._serialized_end=361
  _globals['_GETFEATURESETSTATEBYNAMEREQUEST']._serialized_start=363
  _globals['_GETFEATURESETSTATEBYNAMEREQUEST']._serialized_end=421
  _globals['_GETFEATURESETSTATEBYNAMERESPONSE']._serialized_start=423
  _globals['_GETFEATURESETSTATEBYNAMERESPONSE']._serialized_end=539
  _globals['_GETMULTIFEATURESETSTATEBYIDSREQUEST']._serialized_start=541
  _globals['_GETMULTIFEATURESETSTATEBYIDSREQUEST']._serialized_end=602
  _globals['_GETMULTIFEATURESETSTATEBYIDSRESPONSE']._serialized_start=604
  _globals['_GETMULTIFEATURESETSTATEBYIDSRESPONSE']._serialized_end=725
  _globals['_GETMULTIFEATURESETSTATEBYNAMEREQUEST']._serialized_start=727
  _globals['_GETMULTIFEATURESETSTATEBYNAMEREQUEST']._serialized_end=790
  _globals['_GETMULTIFEATURESETSTATEBYNAMERESPONSE']._serialized_start=792
  _globals['_GETMULTIFEATURESETSTATEBYNAMERESPONSE']._serialized_end=913
  _globals['_UPDATEMULTIEXECUTIONSTATEREQUEST']._serialized_start=915
  _globals['_UPDATEMULTIEXECUTIONSTATEREQUEST']._serialized_end=1029
  _globals['_UPDATEMULTIEXECUTIONSTATERESPONSE']._serialized_start=1031
  _globals['_UPDATEMULTIEXECUTIONSTATERESPONSE']._serialized_end=1066
  _globals['_DELETEFEATURESETSTATEBYIDREQUEST']._serialized_start=1068
  _globals['_DELETEFEATURESETSTATEBYIDREQUEST']._serialized_end=1125
  _globals['_DELETEFEATURESETSTATEBYIDRESPONSE']._serialized_start=1127
  _globals['_DELETEFEATURESETSTATEBYIDRESPONSE']._serialized_end=1191
  _globals['_FEATURESTOREEXECUTIONSTATESERVICE']._serialized_start=1194
  _globals['_FEATURESTOREEXECUTIONSTATESERVICE']._serialized_end=2300
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/serving/serving.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(qwak/feature_store/serving/serving.proto\x12%com.qwak.ai.feature.store.serving.api\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa8\x02\n\x1eRequestedEntitiesMatrixRequest\x12U\n\x14\x65ntities_to_features\x18\x01 \x03(\x0b\x32\x37.com.qwak.ai.feature.store.serving.api.EntityToFeatures\x12\\\n\x14\x65ntity_values_matrix\x18\x02 \x01(\x0b\x32>.com.qwak.ai.feature.store.serving.api.RequestedEntitiesMatrix\x12Q\n\x11request_meta_data\x18\x03 \x01(\x0b\x32\x36.com.qwak.ai.feature.store.serving.api.RequestMetaData\"R\n\x0fRequestMetaData\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x10\n\x08num_keys\x18\x02 \x01(\x05\x12\x19\n\x11\x66\x65\x61ture_set_names\x18\x03 \x03(\t\"\xa5\x01\n\x17RequestedEntitiesMatrix\x12\x45\n\x06header\x18\x01 \x01(\x0b\x32\x35.com.qwak.ai.feature.store.serving.api.EntitiesHeader\x12\x43\n\x04rows\x18\x02 \x03(\x0b\x32\x35.com.qwak.ai.feature.store.serving.api.EntityValueRow\"&\n\x0e\x45ntitiesHeader\x12\x14\n\x0c\x65ntity_names\x18\x01 \x03(\t\"6\n\x0e\x45ntityValueRow\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x15\n\rentity_values\x18\x02 \x03(\t\"i\n\x10\x45ntityToFeatures\x12@\n\x08\x66\x65\x61tures\x18\x01 \x03(\x0b\x32..com.qwak.ai.feature.store.serving.api.Feature\x12\x13\n\x0b\x65ntity_name\x18\x02 \x01(\t\"\xd3\x01\n\x14\x46\x65\x61tureValuesRequest\x12@\n\x08\x66\x65\x61tures\x18\x01 \x03(\x0b\x32..com.qwak.ai.feature.store.serving.api.Feature\x12R\n\x06\x65ntity\x18\x02 \x01(\x0b\x32\x42.com.qwak.ai.feature.store.serving.api.FeatureValuesRequest.Entity\x1a%\n\x06\x45ntity\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xa2\x04\n\x07\x46\x65\x61ture\x12L\n\rbatch_feature\x18\x01 \x01(\x0b\x32\x33.com.qwak.ai.feature.store.serving.api.BatchFeatureH\x00\x12X\n\x12on_the_fly_feature\x18\x02 \x01(\x0b\x32\x36.com.qwak.ai.feature.store.serving.api.OnTheFlyFeatureB\x02\x18\x01H\x00\x12T\n\x11streaming_feature\x18\x03 \x01(\x0b\x32\x37.com.qwak.ai.feature.store.serving.api.StreamingFeatureH\x00\x12\x63\n\x15streaming_aggregation\x18\x04 \x01(\x0b\x32\x42.com.qwak.ai.feature.store.serving.api.StreamingAggregationFeatureH\x00\x12Q\n\x10\x62\x61tch_v1_feature\x18\x05 \x01(\x0b\x32\x35.com.qwak.ai.feature.store.serving.api.BatchV1FeatureH\x00\x12Y\n\x14streaming_v1_feature\x18\x06 \x01(\x0b\x32\x39.com.qwak.ai.feature.store.serving.api.StreamingV1FeatureH\x00\x42\x06\n\x04type\"\x1c\n\x0c\x42\x61tchFeature\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1e\n\x0e\x42\x61tchV1Feature\x12\x0c\n\x04name\x18\x01 \x01(\t\" \n\x10StreamingFeature\x12\x0c\n\x04name\x18\x01 \x01(\t\"\"\n\x12StreamingV1Feature\x12\x0c\n\x04name\x18\x01 \x01(\t\"+\n\x1bStreamingAggregationFeature\x12\x0c\n\x04name\x18\x01 \x01(\t\"u\n\x0fOnTheFlyFeature\x12\x10\n\x04name\x18\x01 \x01(\tB\x02\x18\x01\x12P\n\x0fon_the_fly_data\x18\x02 \x01(\x0b\x32\x33.com.qwak.ai.feature.store.serving.api.OnTheFlyDataB\x02\x18\x01\"O\n\x1aMultiFeatureValuesResponse\x12\x19\n\x11pandas_df_as_json\x18\x01 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_values\x18\x02 \x01(\t\"\xf4\x02\n\x15\x46\x65\x61tureValuesResponse\x12\x61\n\x0e\x66\x65\x61ture_values\x18\x01 \x03(\x0b\x32I.com.qwak.ai.feature.store.serving.api.FeatureValuesResponse.FeatureValue\x1a\xf7\x01\n\x0c\x46\x65\x61tureValue\x12\x14\n\x0c\x66\x65\x61ture_name\x18\x01 \x01(\t\x12\x43\n\rfeature_value\x18\x02 \x01(\x0b\x32,.com.qwak.ai.feature.store.serving.api.Value\x12\x65\n\x06status\x18\x03 \x01(\x0e\x32U.com.qwak.ai.feature.store.serving.api.FeatureValuesResponse.FeatureValue.ValueStatus\"%\n\x0bValueStatus\x12\x0b\n\x07INVALID\x10\x00\x12\t\n\x05VALID\x10\x01\"J\n\x0cOnTheFlyData\x12\x17\n\tuser_data\x18\x01 \x01(\tB\x02\x18\x01H\x00\x12\x19\n\x0bschema_data\x18\x02 \x01(\tB\x02\x18\x01H\x00\x42\x06\n\x04\x64\x61ta\"\x9a\x02\n\x05Value\x12\x13\n\tbytes_val\x18\x01 \x01(\x0cH\x00\x12\x14\n\nstring_val\x18\x02 \x01(\tH\x00\x12\x13\n\tint32_val\x18\x03 \x01(\x05H\x00\x12\x13\n\tint64_val\x18\x04 \x01(\x03H\x00\x12\x14\n\ndouble_val\x18\x05 \x01(\x01H\x00\x12\x13\n\tfloat_val\x18\x06 \x01(\x02H\x00\x12\x12\n\x08\x62ool_val\x18\x07 \x01(\x08H\x00\x12\x33\n\rtimestamp_val\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\x41\n\tarray_val\x18\t \x01(\x0b\x32,.com.qwak.ai.feature.store.serving.api.ArrayH\x00\x42\x05\n\x03val\"H\n\x05\x41rray\x12?\n\tarray_val\x18\x01 \x03(\x0b\x32,.com.qwak.ai.feature.store.serving.api.Value2\xba\x02\n\x0eServingService\x12\x88\x01\n\x0bGetFeatures\x12;.com.qwak.ai.feature.store.serving.api.FeatureValuesRequest\x1a<.com.qwak.ai.feature.store.serving.api.FeatureValuesResponse\x12\x9c\x01\n\x10GetMultiFeatures\x12\x45.com.qwak.ai.feature.store.serving.api.RequestedEntitiesMatrixRequest\x1a\x41.com.qwak.ai.feature.store.serving.api.MultiFeatureValuesResponseB\'\n%com.qwak.ai.feature.store.serving.apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.serving.serving_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.feature.store.serving.api'
  _FEATURE.fields_by_name['on_the_fly_feature']._options = None
  _FEATURE.fields_by_name['on_the_fly_feature']._serialized_options = b'\030\001'
  _ONTHEFLYFEATURE.fields_by_name['name']._options = None
  _ONTHEFLYFEATURE.fields_by_name['name']._serialized_options = b'\030\001'
  _ONTHEFLYFEATURE.fields_by_name['on_the_fly_data']._options = None
  _ONTHEFLYFEATURE.fields_by_name['on_the_fly_data']._serialized_options = b'\030\001'
  _ONTHEFLYDATA.fields_by_name['user_data']._options = None
  _ONTHEFLYDATA.fields_by_name['user_data']._serialized_options = b'\030\001'
  _ONTHEFLYDATA.fields_by_name['schema_data']._options = None
  _ONTHEFLYDATA.fields_by_name['schema_data']._serialized_options = b'\030\001'
  _globals['_REQUESTEDENTITIESMATRIXREQUEST']._serialized_start=117
  _globals['_REQUESTEDENTITIESMATRIXREQUEST']._serialized_end=413
  _globals['_REQUESTMETADATA']._serialized_start=415
  _globals['_REQUESTMETADATA']._serialized_end=497
  _globals['_REQUESTEDENTITIESMATRIX']._serialized_start=500
  _globals['_REQUESTEDENTITIESMATRIX']._serialized_end=665
  _globals['_ENTITIESHEADER']._serialized_start=667
  _globals['_ENTITIESHEADER']._serialized_end=705
  _globals['_ENTITYVALUEROW']._serialized_start=707
  _globals['_ENTITYVALUEROW']._serialized_end=761
  _globals['_ENTITYTOFEATURES']._serialized_start=763
  _globals['_ENTITYTOFEATURES']._serialized_end=868
  _globals['_FEATUREVALUESREQUEST']._serialized_start=871
  _globals['_FEATUREVALUESREQUEST']._serialized_end=1082
  _globals['_FEATUREVALUESREQUEST_ENTITY']._serialized_start=1045
  _globals['_FEATUREVALUESREQUEST_ENTITY']._serialized_end=1082
  _globals['_FEATURE']._serialized_start=1085
  _globals['_FEATURE']._serialized_end=1631
  _globals['_BATCHFEATURE']._serialized_start=1633
  _globals['_BATCHFEATURE']._serialized_end=1661
  _globals['_BATCHV1FEATURE']._serialized_start=1663
  _globals['_BATCHV1FEATURE']._serialized_end=1693
  _globals['_STREAMINGFEATURE']._serialized_start=1695
  _globals['_STREAMINGFEATURE']._serialized_end=1727
  _globals['_STREAMINGV1FEATURE']._serialized_start=1729
  _globals['_STREAMINGV1FEATURE']._serialized_end=1763
  _globals['_STREAMINGAGGREGATIONFEATURE']._serialized_start=1765
  _globals['_STREAMINGAGGREGATIONFEATURE']._serialized_end=1808
  _globals['_ONTHEFLYFEATURE']._serialized_start=1810
  _globals['_ONTHEFLYFEATURE']._serialized_end=1927
  _globals['_MULTIFEATUREVALUESRESPONSE']._serialized_start=1929
  _globals['_MULTIFEATUREVALUESRESPONSE']._serialized_end=2008
  _globals['_FEATUREVALUESRESPONSE']._serialized_start=2011
  _globals['_FEATUREVALUESRESPONSE']._serialized_end=2383
  _globals['_FEATUREVALUESRESPONSE_FEATUREVALUE']._serialized_start=2136
  _globals['_FEATUREVALUESRESPONSE_FEATUREVALUE']._serialized_end=2383
  _globals['_FEATUREVALUESRESPONSE_FEATUREVALUE_VALUESTATUS']._serialized_start=2346
  _globals['_FEATUREVALUESRESPONSE_FEATUREVALUE_VALUESTATUS']._serialized_end=2383
  _globals['_ONTHEFLYDATA']._serialized_start=2385
  _globals['_ONTHEFLYDATA']._serialized_end=2459
  _globals['_VALUE']._serialized_start=2462
  _globals['_VALUE']._serialized_end=2744
  _globals['_ARRAY']._serialized_start=2746
  _globals['_ARRAY']._serialized_end=2818
  _globals['_SERVINGSERVICE']._serialized_start=2821
  _globals['_SERVINGSERVICE']._serialized_end=3135
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/cluster/v2/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.administration.runtime_configuration.v0 import runtime_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_runtime__config__pb2
from _qwak_proto.qwak.administration.runtime_configuration.v0 import network_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_network__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,qwak/administration/cluster/v2/cluster.proto\x12\x1eqwak.administration.cluster.v2\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x41qwak/administration/runtime_configuration/v0/runtime_config.proto\x1a\x41qwak/administration/runtime_configuration/v0/network_config.proto\"\xbb\x01\n\x07\x43luster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12K\n\rconfiguration\x18\x03 \x01(\x0b\x32\x34.qwak.administration.cluster.v2.ClusterConfiguration\x12I\n\x10\x63luster_metadata\x18\x04 \x01(\x0b\x32/.qwak.administration.cluster.v2.ClusterMetadata\"\xa5\x01\n\x0f\x43lusterMetadata\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x02 \x01(\t\x12\x34\n\x10last_modified_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x04 \x01(\t\"\xb1\x02\n\x14\x43lusterConfiguration\x12\\\n\x19self_hosted_configuration\x18\x01 \x01(\x0b\x32\x37.qwak.administration.cluster.v2.SelfHostedConfigurationH\x00\x12^\n\x1aself_service_configuration\x18\x02 \x01(\x0b\x32\x38.qwak.administration.cluster.v2.SelfServiceConfigurationH\x00\x12S\n\x14hybrid_configuration\x18\x03 \x01(\x0b\x32\x33.qwak.administration.cluster.v2.HybridConfigurationH\x00\x42\x06\n\x04type\"n\n\x17SelfHostedConfiguration\x12S\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x34.qwak.administration.cluster.v2.RuntimeConfiguration\"o\n\x18SelfServiceConfiguration\x12S\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x34.qwak.administration.cluster.v2.RuntimeConfiguration\"j\n\x13HybridConfiguration\x12S\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x34.qwak.administration.cluster.v2.RuntimeConfiguration\"\xf2\x01\n\x14RuntimeConfiguration\x12\x61\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x42.qwak.administration.runtime_configuration.v0.RuntimeConfiguration\x12w\n\x15network_configuration\x18\x02 \x01(\x0b\x32X.qwak.administration.runtime_configuration.v0.network_config.ClusterNetworkConfiguration\"y\n\x0b\x43lusterSpec\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12T\n\x12\x63onfiguration_spec\x18\x02 \x01(\x0b\x32\x38.qwak.administration.cluster.v2.ClusterConfigurationSpec\"\xc1\x02\n\x18\x43lusterConfigurationSpec\x12`\n\x19self_hosted_configuration\x18\x01 \x01(\x0b\x32;.qwak.administration.cluster.v2.SelfHostedConfigurationSpecH\x00\x12\x62\n\x1aself_service_configuration\x18\x02 \x01(\x0b\x32<.qwak.administration.cluster.v2.SelfServiceConfigurationSpecH\x00\x12W\n\x14hybrid_configuration\x18\x03 \x01(\x0b\x32\x37.qwak.administration.cluster.v2.HybridConfigurationSpecH\x00\x42\x06\n\x04type\"v\n\x1bSelfHostedConfigurationSpec\x12W\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x38.qwak.administration.cluster.v2.RuntimeConfigurationSpec\"w\n\x1cSelfServiceConfigurationSpec\x12W\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x38.qwak.administration.cluster.v2.RuntimeConfigurationSpec\"r\n\x17HybridConfigurationSpec\x12W\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x38.qwak.administration.cluster.v2.RuntimeConfigurationSpec\"\xf6\x01\n\x18RuntimeConfigurationSpec\x12\x61\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x42.qwak.administration.runtime_configuration.v0.RuntimeConfiguration\x12w\n\x15network_configuration\x18\x02 \x01(\x0b\x32X.qwak.administration.runtime_configuration.v0.network_config.ClusterNetworkConfiguration\"V\n\x0c\x43lusterState\x12=\n\x05valid\x18\x01 \x01(\x0b\x32,.qwak.administration.cluster.v2.ClusterValidH\x00\x42\x07\n\x05state\"H\n\x0c\x43lusterValid\x12\x38\n\x07\x63luster\x18\x01 \x01(\x0b\x32\'.qwak.administration.cluster.v2.Cluster\"b\n\x0c\x43lusterBrief\x12R\n\x11installation_type\x18\x01 \x01(\x0e\x32\x37.qwak.administration.cluster.v2.ClusterInstallationType*\xbd\x01\n\x17\x43lusterInstallationType\x12%\n!CLUSTER_INSTALLATION_TYPE_INVALID\x10\x00\x12)\n%SELF_HOSTED_CLUSTER_INSTALLATION_TYPE\x10\x01\x12*\n&SELF_SERVICE_CLUSTER_INSTALLATION_TYPE\x10\x02\x12$\n HYBRID_CLUSTER_INSTALLATION_TYPE\x10\x03\x42\xb4\x01\n)com.qwak.ai.administration.api.cluster.v2P\x01Z\x84\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/cluster/v2;cluster_v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.cluster.v2.cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.qwak.ai.administration.api.cluster.v2P\001Z\204\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/cluster/v2;cluster_v2'
  _globals['_CLUSTERINSTALLATIONTYPE']._serialized_start=2807
  _globals['_CLUSTERINSTALLATIONTYPE']._serialized_end=2996
  _globals['_CLUSTER']._serialized_start=248
  _globals['_CLUSTER']._serialized_end=435
  _globals['_CLUSTERMETADATA']._serialized_start=438
  _globals['_CLUSTERMETADATA']._serialized_end=603
  _globals['_CLUSTERCONFIGURATION']._serialized_start=606
  _globals['_CLUSTERCONFIGURATION']._serialized_end=911
  _globals['_SELFHOSTEDCONFIGURATION']._serialized_start=913
  _globals['_SELFHOSTEDCONFIGURATION']._serialized_end=1023
  _globals['_SELFSERVICECONFIGURATION']._serialized_start=1025
  _globals['_SELFSERVICECONFIGURATION']._serialized_end=1136
  _globals['_HYBRIDCONFIGURATION']._serialized_start=1138
  _globals['_HYBRIDCONFIGURATION']._serialized_end=1244
  _globals['_RUNTIMECONFIGURATION']._serialized_start=1247
  _globals['_RUNTIMECONFIGURATION']._serialized_end=1489
  _globals['_CLUSTERSPEC']._serialized_start=1491
  _globals['_CLUSTERSPEC']._serialized_end=1612
  _globals['_CLUSTERCONFIGURATIONSPEC']._serialized_start=1615
  _globals['_CLUSTERCONFIGURATIONSPEC']._serialized_end=1936
  _globals['_SELFHOSTEDCONFIGURATIONSPEC']._serialized_start=1938
  _globals['_SELFHOSTEDCONFIGURATIONSPEC']._serialized_end=2056
  _globals['_SELFSERVICECONFIGURATIONSPEC']._serialized_start=2058
  _globals['_SELFSERVICECONFIGURATIONSPEC']._serialized_end=2177
  _globals['_HYBRIDCONFIGURATIONSPEC']._serialized_start=2179
  _globals['_HYBRIDCONFIGURATIONSPEC']._serialized_end=2293
  _globals['_RUNTIMECONFIGURATIONSPEC']._serialized_start=2296
  _globals['_RUNTIMECONFIGURATIONSPEC']._serialized_end=2542
  _globals['_CLUSTERSTATE']._serialized_start=2544
  _globals['_CLUSTERSTATE']._serialized_end=2630
  _globals['_CLUSTERVALID']._serialized_start=2632
  _globals['_CLUSTERVALID']._serialized_end=2704
  _globals['_CLUSTERBRIEF']._serialized_start=2706
  _globals['_CLUSTERBRIEF']._serialized_end=2804
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.ecosystem.jfrog.v0 import token_service_pb2 as qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__service__pb2


class TokenServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GenerateToken = channel.unary_unary(
                '/qwak.ecosystem.jfrog.token.v0.TokenService/GenerateToken',
                request_serializer=qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__service__pb2.GenerateTokenRequest.SerializeToString,
                response_deserializer=qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__service__pb2.GenerateTokenResponse.FromString,
                )
        self.GenerateArtifactoryImagePullToken = channel.unary_unary(
                '/qwak.ecosystem.jfrog.token.v0.TokenService/GenerateArtifactoryImagePullToken',
                request_serializer=qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__service__pb2.GenerateArtifactoryImagePullTokenRequest.SerializeToString,
                response_deserializer=qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__service__pb2.GenerateArtifactoryImagePullTokenResponse.FromString,
                )
        self.PersistTokenClaims = channel.unary_unary(
                '/qwak.ecosystem.jfrog.token.v0.TokenService/PersistTokenClaims',
                request_serializer=qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__service__pb2.PersistTokenClaimsRequest.SerializeToString,
                response_deserializer=qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__service__pb2.PersistTokenClaimsResponse.FromString,
                )
        self.RevokeToken = channel.unary_unary(
                '/qwak.ecosystem.jfrog.token.v0.TokenService/RevokeToken',
                request_serializer=qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__service__pb2.RevokeTokenRequest.SerializeToString,
                response_deserializer=qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__service__pb2.RevokeTokenRequestResponse.FromString,
                )


class TokenServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GenerateToken(self, request, context):
        """Generate token
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateArtifactoryImagePullToken(self, request, context):
        """Generate artifactory pull image token
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PersistTokenClaims(self, request, context):
        """Persist token claims for later usage
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevokeToken(self, request, context):
        """Revoke token
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TokenServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GenerateToken': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateToken,
                    request_deserializer=qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__service__pb2.GenerateTokenRequest.FromString,
                    response_serializer=qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__service__pb2.GenerateTokenResponse.SerializeToString,
            ),
            'GenerateArtifactoryImagePullToken': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateArtifactoryImagePullToken,
                    request_deserializer=qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__service__pb2.GenerateArtifactoryImagePullTokenRequest.FromString,
                    response_serializer=qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__service__pb2.GenerateArtifactoryImagePullTokenResponse.SerializeToString,
            ),
            'PersistTokenClaims': grpc.unary_unary_rpc_method_handler(
                    servicer.PersistTokenClaims,
                    request_deserializer=qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__service__pb2.PersistTokenClaimsRequest.FromString,
                    response_serializer=qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__service__pb2.PersistTokenClaimsResponse.SerializeToString,
            ),
            'RevokeToken': grpc.unary_unary_rpc_method_handler(
                    servicer.RevokeToken,
                    request_deserializer=qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__service__pb2.RevokeTokenRequest.FromString,
                    response_serializer=qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__service__pb2.RevokeTokenRequestResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.ecosystem.jfrog.token.v0.TokenService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TokenService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GenerateToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.ecosystem.jfrog.token.v0.TokenService/GenerateToken',
            qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__service__pb2.GenerateTokenRequest.SerializeToString,
            qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__service__pb2.GenerateTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GenerateArtifactoryImagePullToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.ecosystem.jfrog.token.v0.TokenService/GenerateArtifactoryImagePullToken',
            qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__service__pb2.GenerateArtifactoryImagePullTokenRequest.SerializeToString,
            qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__service__pb2.GenerateArtifactoryImagePullTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PersistTokenClaims(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.ecosystem.jfrog.token.v0.TokenService/PersistTokenClaims',
            qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__service__pb2.PersistTokenClaimsRequest.SerializeToString,
            qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__service__pb2.PersistTokenClaimsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RevokeToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.ecosystem.jfrog.token.v0.TokenService/RevokeToken',
            qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__service__pb2.RevokeTokenRequest.SerializeToString,
            qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__service__pb2.RevokeTokenRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import importlib.util
import os
import shutil
import subprocess  # nosec
from dataclasses import dataclass, field
from pathlib import Path
from typing import List

from qwak.inner.build_logic.constants.temp_dir import TEMP_LOCAL_MODEL_DIR
from qwak.inner.build_logic.dependency_manager_type import DependencyManagerType

from qwak.inner.build_logic.interface.step_inteface import Step
from qwak.exceptions import QwakSuggestionException
from qwak.inner.build_logic.tools.dependencies_tools import find_dependency_files

TEMP_LOCAL_EDITABLE_FOLDER = "editable"


@dataclass
class DependencyFileObject:
    dep_file_name: List[str]
    lock_file_name: str = field(default="")


DEPS_MANAGER_FILE_MAP = {
    DependencyManagerType.PIP: DependencyFileObject(dep_file_name=["requirements.txt"]),
    DependencyManagerType.POETRY: DependencyFileObject(
        dep_file_name=["pyproject.toml"], lock_file_name="poetry.lock"
    ),
    DependencyManagerType.CONDA: DependencyFileObject(
        dep_file_name=["conda.yml", "conda.yaml"]
    ),
}


class PostFetchValidationStep(Step):
    STEP_DESCRIPTION = "Post model fetch validation"

    def description(self) -> str:
        return self.STEP_DESCRIPTION

    def execute(self) -> None:
        self.validate_dependencies()
        self.configure_base_docker_image()
        self.create_development_wheels()

    def validate_dependencies(self):
        if (
            not Path(self.config.build_properties.model_uri.uri).is_dir()
            or self.config.build_env.python_env.dependency_file_path
        ):
            self.build_logger.debug("Validating dependency file exists")
            model_uri, main_dir = (
                self.context.host_temp_local_build_dir / TEMP_LOCAL_MODEL_DIR,
                self.config.build_properties.model_uri.main_dir,
            )
            (
                self.context.dependency_manager_type,
                self.context.model_relative_dependency_file,
                self.context.model_relative_dependency_lock_file,
            ) = find_dependency_files(model_uri, main_dir, self.build_logger)

            if (
                self.context.dependency_manager_type
                and self.context.model_relative_dependency_file
            ):
                return

            self.build_logger.error("Dependency file wasn't found, failing...")
            raise QwakSuggestionException(
                message="Dependency file isn't found",
                suggestion="Make sure your model include one of dependencies manager: pip/poetry/conda",
            )

    def configure_base_docker_image(self):
        base_image = self.config.build_env.docker.base_image
        if (not base_image) and self.config.build_env.remote.resources.gpu_type:
            base_image = "qwakai/qwak:gpu-py39"
        self.context.base_image = base_image

    def create_development_wheels(self):
        if not os.getenv("QWAK_DEBUG"):
            return

        (module_location,) = importlib.util.find_spec(
            "qwak_sdk"
        ).submodule_search_locations
        source_dir = Path(module_location).parent
        pyproject_toml = source_dir / "pyproject.toml"

        if pyproject_toml.is_file():
            self.build_logger.info(
                "Detected non-PyPI-released qwak-sdk installed, creating local qwak-runtime "
                "and qwak-core wheel files to pass to build process"
            )
            runtime_dir = source_dir.parent / "qwak-runtime"
            core_dir = source_dir.parent / "qwak-core"
            target_path = self.context.host_temp_local_build_dir
            self.context.custom_runtime_wheel = self._create_wheel(
                runtime_dir, target_path
            )
            self.context.custom_core_wheel = self._create_wheel(core_dir, target_path)

    def _create_wheel(self, package_dir, target_path):
        dist_dir = package_dir / "dist"
        shutil.rmtree(dist_dir, ignore_errors=True)
        output = subprocess.check_output(["make", "sync"], cwd=package_dir)  # nosec
        for line in output.decode().split("\n"):
            self.build_logger.debug(f">>> {line}")
        output = subprocess.check_output(["poetry", "build"], cwd=package_dir)  # nosec
        for line in output.decode().split("\n"):
            self.build_logger.debug(f">>> {line}")
        wheel_file = next(dist_dir.glob("*.whl"), None)
        editable_folder = target_path / TEMP_LOCAL_EDITABLE_FOLDER
        editable_folder.mkdir(exist_ok=True)
        copied_wheel_file = shutil.move(wheel_file, editable_folder / wheel_file.name)
        shutil.rmtree(dist_dir, ignore_errors=True)
        self.build_logger.info(f"Created wheel for {package_dir} successfully")
        return copied_wheel_file


def find_file_location(model_uri, main_dir, filename) -> Path:
    file_locations: List[Path] = [
        model_uri / filename,
        model_uri / main_dir / filename,
    ]
    for file in file_locations:
        if file.is_file():
            return file


def get_possible_dependency_lock_paths(dependency_path: Path):
    paths = []
    for _, dependency_file_object in DEPS_MANAGER_FILE_MAP.items():
        if dependency_file_object.lock_file_name:
            lock_file_path = (
                dependency_path.parent / dependency_file_object.lock_file_name
            )
            paths.append(lock_file_path)
    return paths



from typing import Dict, Optional

import grpc
from _qwak_proto.qwak.feature_store.entities.entity_pb2 import Entity
from _qwak_proto.qwak.feature_store.features.feature_set_types_pb2 import (
    BatchFeatureSetV1,
    StreamingAggregationFeatureSet,
    StreamingFeatureSetV1,
)
from _qwak_proto.qwak.kube_deployment_captain.feature_set_deployment_pb2 import (
    BatchDetails,
    FeatureSetDeployment,
)
from _qwak_proto.qwak.kube_deployment_captain.kube_deployment_captain_service_pb2 import (
    BatchFeatureSetV1DeploymentRequest,
    DeployFeatureSetResponse,
    DeployStreamingAggregationCompactionRequest,
    DeployStreamingAggregationCompactionResponse,
    StreamingFeatureSetV1DeploymentRequest,
    UndeployBatchFeaturesetRequest,
    UndeployFeatureSetRequest,
    UndeployFeatureSetResponse,
)
from _qwak_proto.qwak.kube_deployment_captain.kube_deployment_captain_service_pb2_grpc import (
    KubeDeploymentCaptainStub,
)
from google.protobuf.timestamp_pb2 import Timestamp
from qwak.exceptions import QwakException
from qwak.inner.tool.grpc.grpc_tools import create_grpc_channel


class KubeDeploymentClient:
    """
    Used for interacting with Kube Deployment Captain
    """

    def __init__(
        self,
        edge_services_url: str,
        enable_ssl: bool = True,
        grpc_channel: Optional[grpc.Channel] = None,
    ):
        self._channel = None

        if grpc_channel:
            self._channel = grpc_channel
        else:
            self._channel = create_grpc_channel(
                url=edge_services_url,
                enable_ssl=enable_ssl,
                status_for_retry=(
                    grpc.StatusCode.UNAVAILABLE,
                    grpc.StatusCode.DEADLINE_EXCEEDED,
                    grpc.StatusCode.INTERNAL,
                ),
            )

        self._kube_deployment = KubeDeploymentCaptainStub(self._channel)

    def deploy_streaming_offline_feature_set(
        self,
        feature_set_name: str,
        streaming_feature_set: StreamingFeatureSetV1,
        extra_deployment_configuration: Optional[Dict[str, str]],
        extra_env_configuration: Optional[Dict[str, str]],
        entity: Entity,
        feature_set_id: str,
        environment_id: str,
        secret_service_url: Optional[str],
        run_id: Optional[int] = 0,
    ) -> DeployFeatureSetResponse:
        """
        Deploy streaming offline feature set
        Args: feature_set_name: Name of the feature set
              extra_deployment_configuration: Dictionary of spark configuration
              extra_env_configuration: Environment configuration
              Entity: entity of the feature set
              feature_set_id: Feature set id
              environment_id: Environment id
              secret_service_url: Secret service of the url

        Return: DeployFeatureSetResponse
        """
        try:
            streaming_featureset_request = StreamingFeatureSetV1DeploymentRequest(
                feature_set_deployment=FeatureSetDeployment(
                    featureset_name=feature_set_name,
                    featureset_id=feature_set_id,
                    streaming_feature_set=streaming_feature_set,
                    extra_deployment_configuration=extra_deployment_configuration,
                    extra_env_configuration=extra_env_configuration,
                    entity=entity,
                    secret_service_url=secret_service_url,
                    run_id=run_id,
                ),
                environment_id=environment_id,
            )

            return self._kube_deployment.DeployStreamingOfflineFeatureSetV1(
                streaming_featureset_request
            )
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to deploy offline streaming feature set, error is {repr(e)}"
            )

    def deploy_batch_feature_set(
        self,
        featureset_name: str,
        featureset_id: str,
        batch_featureset: BatchFeatureSetV1,
        extra_deployment_configuration: Optional[Dict[str, str]],
        extra_env_configuration: Optional[Dict[str, str]],
        entity: Entity,
        secret_service_url: str,
        job_run_id: int,
        environment_id: str,
        batch_execution_date: Timestamp,
        try_number: int,
        batch_trigger_date: Timestamp,
    ) -> DeployFeatureSetResponse:
        """
        Deploy batch featureset
        Args: featureset_name: Name of the feature set
              featureset_id: Id of the featureset
              batch_featureset: batch featureset definition
              extra_deployment_configuration: Dictionary of spark configuration
              extra_env_configuration: Environment configuration
              Entity: entity of the feature set
              secret_service_url: Secret service of the url
              job_run_id: the run id of the job
              environment_id: Environment id
              batch_execution_date: the current batch execution time
              prev_batch_execution_date: previous batch exection time
              prev_ingestion_window_date: previous ingestion window time
              batch_trigger_date: system trigger date
        Return: DeployFeatureSetResponse
        """
        try:
            batch_featureset_request = BatchFeatureSetV1DeploymentRequest(
                feature_set_deployment=FeatureSetDeployment(
                    featureset_name=featureset_name,
                    featureset_id=featureset_id,
                    batch_feature_set=batch_featureset,
                    extra_deployment_configuration=extra_deployment_configuration,
                    extra_env_configuration=extra_env_configuration,
                    secret_service_url=secret_service_url,
                    entity=entity,
                    run_id=job_run_id,
                ),
                batch_details=BatchDetails(
                    batch_execution_date=batch_execution_date,
                    try_number=try_number,
                    batch_trigger_date=batch_trigger_date,
                ),
                environment_id=environment_id,
            )
            return self._kube_deployment.DeployBatchFeatureSetV1(
                batch_featureset_request
            )
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to deploy batch feature set, error is {repr(e)}"
            )

    def deploy_streaming_aggregation_compaction(
        self,
        feature_set_id: str,
        feature_set_name: str,
        environment_id: str,
        streaming_aggregation_feature_set: StreamingAggregationFeatureSet,
        entity: Entity,
        extra_deployment_configuration: Optional[Dict[str, str]],
        extra_env_configuration: Optional[Dict[str, str]],
        secret_service_url: str,
        job_run_id: int,
    ) -> DeployStreamingAggregationCompactionResponse:
        try:
            streaming_aggregation_compaction_deploy_request: (
                DeployStreamingAggregationCompactionRequest
            ) = DeployStreamingAggregationCompactionRequest(
                feature_set_deployment=FeatureSetDeployment(
                    featureset_name=feature_set_name,
                    featureset_id=feature_set_id,
                    streaming_aggregation_feature_set=streaming_aggregation_feature_set,
                    extra_deployment_configuration=extra_deployment_configuration,
                    extra_env_configuration=extra_env_configuration,
                    entity=entity,
                    secret_service_url=secret_service_url,
                    run_id=job_run_id,
                ),
                environment_id=environment_id,
            )
            return self._kube_deployment.DeployStreamingAggregationCompaction(
                streaming_aggregation_compaction_deploy_request
            )
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to deploy streaming aggregation feature set, error is {repr(e)}"
            )

    def undeploy_featureset_resources(
        self, featureset_name: str
    ) -> UndeployFeatureSetResponse:
        """
        Undeploy featureset by name. Delete all spark resources.
        """
        try:
            undeploy_request: UndeployFeatureSetRequest = UndeployFeatureSetRequest(
                feature_set_name=featureset_name
            )
            return self._kube_deployment.UndeployFeatureSet(undeploy_request)
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to undeploy featureset: {featureset_name}, error is {repr(e)}"
            )

    def undeploy_batch_featureset(
        self, featureset_name: str
    ) -> UndeployFeatureSetResponse:
        """
        Undeploy featureset by name. Delete all spark resources.
        """
        try:
            undeploy_request: UndeployBatchFeaturesetRequest = (
                UndeployBatchFeaturesetRequest(featureset_name=featureset_name)
            )
            return self._kube_deployment.UndeployBatchFeatureset(undeploy_request)
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to undeploy batch featureset: {featureset_name}, error is {repr(e)}"
            )



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _JobState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _JobStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_JobState.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVALID: _JobState.ValueType  # 0
    """Invalid job state"""
    PENDING: _JobState.ValueType  # 1
    """The job is pending"""
    RUNNING: _JobState.ValueType  # 2
    """The job is running"""
    COMPLETED: _JobState.ValueType  # 3
    """The job has completed"""
    FAILED: _JobState.ValueType  # 4
    """The job has failed"""
    FAILED_CLUSTER_INIT: _JobState.ValueType  # 5
    """Cluster init failed"""
    CLUSTER_INIT: _JobState.ValueType  # 6
    """Spark cluster initializing"""

class JobState(_JobState, metaclass=_JobStateEnumTypeWrapper): ...

INVALID: JobState.ValueType  # 0
"""Invalid job state"""
PENDING: JobState.ValueType  # 1
"""The job is pending"""
RUNNING: JobState.ValueType  # 2
"""The job is running"""
COMPLETED: JobState.ValueType  # 3
"""The job has completed"""
FAILED: JobState.ValueType  # 4
"""The job has failed"""
FAILED_CLUSTER_INIT: JobState.ValueType  # 5
"""Cluster init failed"""
CLUSTER_INIT: JobState.ValueType  # 6
"""Spark cluster initializing"""
global___JobState = JobState

class JobRecord(google.protobuf.message.Message):
    """Feature Store Batch Job Record.
    Represents a  batch job generated from a batch feature set
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    TRY_NUMBER_FIELD_NUMBER: builtins.int
    JOB_STATE_FIELD_NUMBER: builtins.int
    CREATION_TIME_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    INGESTION_WINDOW_FIELD_NUMBER: builtins.int
    INGESTION_MESSAGE_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    """Unique id of the job"""
    feature_set_name: builtins.str
    """Batch feature set name the record resulted from"""
    try_number: builtins.int
    """Try count"""
    job_state: global___JobState.ValueType
    """State of the job - whether it's running, failed, pending, etc"""
    @property
    def creation_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation time"""
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Start time"""
    @property
    def end_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """End time"""
    @property
    def ingestion_window(self) -> global___IngestionWindow:
        """Ingestion window information"""
    ingestion_message: builtins.str
    """Ingestion message"""
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
        feature_set_name: builtins.str = ...,
        try_number: builtins.int = ...,
        job_state: global___JobState.ValueType = ...,
        creation_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ingestion_window: global___IngestionWindow | None = ...,
        ingestion_message: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creation_time", b"creation_time", "end_time", b"end_time", "ingestion_window", b"ingestion_window", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_time", b"creation_time", "end_time", b"end_time", "feature_set_name", b"feature_set_name", "ingestion_message", b"ingestion_message", "ingestion_window", b"ingestion_window", "job_id", b"job_id", "job_state", b"job_state", "start_time", b"start_time", "try_number", b"try_number"]) -> None: ...

global___JobRecord = JobRecord

class ElaborateJobRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_RECORD_FIELD_NUMBER: builtins.int
    STATUS_MESSAGE_FIELD_NUMBER: builtins.int
    ERROR_TECHNICAL_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def job_record(self) -> global___JobRecord:
        """Job record with persisted job info"""
    status_message: builtins.str
    """User friendly message describing the jobs' status"""
    error_technical_details: builtins.str
    """Error technical details"""
    def __init__(
        self,
        *,
        job_record: global___JobRecord | None = ...,
        status_message: builtins.str = ...,
        error_technical_details: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["job_record", b"job_record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["error_technical_details", b"error_technical_details", "job_record", b"job_record", "status_message", b"status_message"]) -> None: ...

global___ElaborateJobRecord = ElaborateJobRecord

class IngestionWindow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INGESTED_DATA_START_TIME_FIELD_NUMBER: builtins.int
    INGESTED_DATA_END_TIME_FIELD_NUMBER: builtins.int
    INGESTED_DATA_UPDATED_ROWS_FIELD_NUMBER: builtins.int
    BATCH_EXECUTION_TIME_FIELD_NUMBER: builtins.int
    @property
    def ingested_data_start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Ingested data window start time"""
    @property
    def ingested_data_end_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Ingested data window end time"""
    ingested_data_updated_rows: builtins.int
    """Ingested data number of updated rows"""
    @property
    def batch_execution_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Ingested data batch execution date"""
    def __init__(
        self,
        *,
        ingested_data_start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ingested_data_end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ingested_data_updated_rows: builtins.int = ...,
        batch_execution_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["batch_execution_time", b"batch_execution_time", "ingested_data_end_time", b"ingested_data_end_time", "ingested_data_start_time", b"ingested_data_start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_execution_time", b"batch_execution_time", "ingested_data_end_time", b"ingested_data_end_time", "ingested_data_start_time", b"ingested_data_start_time", "ingested_data_updated_rows", b"ingested_data_updated_rows"]) -> None: ...

global___IngestionWindow = IngestionWindow



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/audience/v1/audience_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.audience.v1 import audience_pb2 as qwak_dot_audience_dot_v1_dot_audience__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#qwak/audience/v1/audience_api.proto\x12\x10qwak.audience.v1\x1a\x1fqwak/audience/v1/audience.proto\"E\n\x15\x43reateAudienceRequest\x12,\n\x08\x61udience\x18\x01 \x01(\x0b\x32\x1a.qwak.audience.v1.Audience\"-\n\x16\x43reateAudienceResponse\x12\x13\n\x0b\x61udience_id\x18\x01 \x01(\t\"Q\n\x15UpdateAudienceRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12,\n\x08\x61udience\x18\x03 \x01(\x0b\x32\x1a.qwak.audience.v1.Audience\"\x18\n\x16UpdateAudienceResponse\")\n\x12GetAudienceRequest\x12\x13\n\x0b\x61udience_id\x18\x01 \x01(\t\"C\n\x13GetAudienceResponse\x12,\n\x08\x61udience\x18\x01 \x01(\x0b\x32\x1a.qwak.audience.v1.Audience\"\x15\n\x13ListAudienceRequest\"Q\n\x14ListAudienceResponse\x12\x39\n\x10\x61udience_entries\x18\x01 \x03(\x0b\x32\x1f.qwak.audience.v1.AudienceEntry\",\n\x15\x44\x65leteAudienceRequest\x12\x13\n\x0b\x61udience_id\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteAudienceResponse\".\n\x14SyncAudiencesRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"\x17\n\x15SyncAudiencesResponse2\xd9\x04\n\x0b\x41udienceAPI\x12\x63\n\x0e\x43reateAudience\x12\'.qwak.audience.v1.CreateAudienceRequest\x1a(.qwak.audience.v1.CreateAudienceResponse\x12\x63\n\x0eUpdateAudience\x12\'.qwak.audience.v1.UpdateAudienceRequest\x1a(.qwak.audience.v1.UpdateAudienceResponse\x12Z\n\x0bGetAudience\x12$.qwak.audience.v1.GetAudienceRequest\x1a%.qwak.audience.v1.GetAudienceResponse\x12]\n\x0cListAudience\x12%.qwak.audience.v1.ListAudienceRequest\x1a&.qwak.audience.v1.ListAudienceResponse\x12\x63\n\x0e\x44\x65leteAudience\x12\'.qwak.audience.v1.DeleteAudienceRequest\x1a(.qwak.audience.v1.DeleteAudienceResponse\x12`\n\rSyncAudiences\x12&.qwak.audience.v1.SyncAudiencesRequest\x1a\'.qwak.audience.v1.SyncAudiencesResponseBE\n\x14\x63om.qwak.audience.v1B\x10\x41udienceAPIProtoP\x01Z\x19qwak/audience/v1;audienceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.audience.v1.audience_api_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024com.qwak.audience.v1B\020AudienceAPIProtoP\001Z\031qwak/audience/v1;audience'
  _globals['_CREATEAUDIENCEREQUEST']._serialized_start=90
  _globals['_CREATEAUDIENCEREQUEST']._serialized_end=159
  _globals['_CREATEAUDIENCERESPONSE']._serialized_start=161
  _globals['_CREATEAUDIENCERESPONSE']._serialized_end=206
  _globals['_UPDATEAUDIENCEREQUEST']._serialized_start=208
  _globals['_UPDATEAUDIENCEREQUEST']._serialized_end=289
  _globals['_UPDATEAUDIENCERESPONSE']._serialized_start=291
  _globals['_UPDATEAUDIENCERESPONSE']._serialized_end=315
  _globals['_GETAUDIENCEREQUEST']._serialized_start=317
  _globals['_GETAUDIENCEREQUEST']._serialized_end=358
  _globals['_GETAUDIENCERESPONSE']._serialized_start=360
  _globals['_GETAUDIENCERESPONSE']._serialized_end=427
  _globals['_LISTAUDIENCEREQUEST']._serialized_start=429
  _globals['_LISTAUDIENCEREQUEST']._serialized_end=450
  _globals['_LISTAUDIENCERESPONSE']._serialized_start=452
  _globals['_LISTAUDIENCERESPONSE']._serialized_end=533
  _globals['_DELETEAUDIENCEREQUEST']._serialized_start=535
  _globals['_DELETEAUDIENCEREQUEST']._serialized_end=579
  _globals['_DELETEAUDIENCERESPONSE']._serialized_start=581
  _globals['_DELETEAUDIENCERESPONSE']._serialized_end=605
  _globals['_SYNCAUDIENCESREQUEST']._serialized_start=607
  _globals['_SYNCAUDIENCESREQUEST']._serialized_end=653
  _globals['_SYNCAUDIENCESRESPONSE']._serialized_start=655
  _globals['_SYNCAUDIENCESRESPONSE']._serialized_end=678
  _globals['_AUDIENCEAPI']._serialized_start=681
  _globals['_AUDIENCEAPI']._serialized_end=1282
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.administration.runtime_configuration.v0.creds.secret_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AWSAuthMethod(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AWS_SECURITY_TOKEN_SERVICE_FIELD_NUMBER: builtins.int
    @property
    def aws_security_token_service(self) -> global___AWSSecurityTokenService: ...
    def __init__(
        self,
        *,
        aws_security_token_service: global___AWSSecurityTokenService | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth_type", b"auth_type", "aws_security_token_service", b"aws_security_token_service"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_type", b"auth_type", "aws_security_token_service", b"aws_security_token_service"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth_type", b"auth_type"]) -> typing_extensions.Literal["aws_security_token_service"] | None: ...

global___AWSAuthMethod = AWSAuthMethod

class AWSSecurityTokenService(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_KEY_REF_FIELD_NUMBER: builtins.int
    @property
    def secret_key_ref(self) -> qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef: ...
    def __init__(
        self,
        *,
        secret_key_ref: qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["location", b"location", "secret_key_ref", b"secret_key_ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "secret_key_ref", b"secret_key_ref"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["location", b"location"]) -> typing_extensions.Literal["secret_key_ref"] | None: ...

global___AWSSecurityTokenService = AWSSecurityTokenService

class AWSScopedPermissions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKLOAD_SCOPE_FIELD_NUMBER: builtins.int
    @property
    def workload_scope(self) -> global___AWSWorkloadPermissionScope: ...
    def __init__(
        self,
        *,
        workload_scope: global___AWSWorkloadPermissionScope | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["scope_type", b"scope_type", "workload_scope", b"workload_scope"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["scope_type", b"scope_type", "workload_scope", b"workload_scope"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["scope_type", b"scope_type"]) -> typing_extensions.Literal["workload_scope"] | None: ...

global___AWSScopedPermissions = AWSScopedPermissions

class AWSWorkloadPermissionScope(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ANALYTICS_SCOPE_FIELD_NUMBER: builtins.int
    BATCH_INFERENCE_JOB_SCOPE_FIELD_NUMBER: builtins.int
    FEATURE_STORE_SCOPE_FIELD_NUMBER: builtins.int
    REMOTE_BUILD_JOB_SCOPE_FIELD_NUMBER: builtins.int
    @property
    def analytics_scope(self) -> global___AnalyticsPermissionScope: ...
    @property
    def batch_inference_job_scope(self) -> global___BatchInferenceJobPermissionScope: ...
    @property
    def feature_store_scope(self) -> global___FeatureStorePermissionScope: ...
    @property
    def remote_build_job_scope(self) -> global___RemoteBuildJobPermissionScope: ...
    def __init__(
        self,
        *,
        analytics_scope: global___AnalyticsPermissionScope | None = ...,
        batch_inference_job_scope: global___BatchInferenceJobPermissionScope | None = ...,
        feature_store_scope: global___FeatureStorePermissionScope | None = ...,
        remote_build_job_scope: global___RemoteBuildJobPermissionScope | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["analytics_scope", b"analytics_scope", "batch_inference_job_scope", b"batch_inference_job_scope", "feature_store_scope", b"feature_store_scope", "remote_build_job_scope", b"remote_build_job_scope"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["analytics_scope", b"analytics_scope", "batch_inference_job_scope", b"batch_inference_job_scope", "feature_store_scope", b"feature_store_scope", "remote_build_job_scope", b"remote_build_job_scope"]) -> None: ...

global___AWSWorkloadPermissionScope = AWSWorkloadPermissionScope

class AnalyticsPermissionScope(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTH_METHOD_FIELD_NUMBER: builtins.int
    @property
    def auth_method(self) -> global___AWSAuthMethod: ...
    def __init__(
        self,
        *,
        auth_method: global___AWSAuthMethod | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth_method", b"auth_method"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_method", b"auth_method"]) -> None: ...

global___AnalyticsPermissionScope = AnalyticsPermissionScope

class BatchInferenceJobPermissionScope(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTH_METHOD_FIELD_NUMBER: builtins.int
    @property
    def auth_method(self) -> global___AWSAuthMethod: ...
    def __init__(
        self,
        *,
        auth_method: global___AWSAuthMethod | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth_method", b"auth_method"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_method", b"auth_method"]) -> None: ...

global___BatchInferenceJobPermissionScope = BatchInferenceJobPermissionScope

class FeatureStorePermissionScope(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTH_METHOD_FIELD_NUMBER: builtins.int
    @property
    def auth_method(self) -> global___AWSAuthMethod: ...
    def __init__(
        self,
        *,
        auth_method: global___AWSAuthMethod | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth_method", b"auth_method"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_method", b"auth_method"]) -> None: ...

global___FeatureStorePermissionScope = FeatureStorePermissionScope

class RemoteBuildJobPermissionScope(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTH_METHOD_FIELD_NUMBER: builtins.int
    @property
    def auth_method(self) -> global___AWSAuthMethod: ...
    def __init__(
        self,
        *,
        auth_method: global___AWSAuthMethod | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth_method", b"auth_method"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_method", b"auth_method"]) -> None: ...

global___RemoteBuildJobPermissionScope = RemoteBuildJobPermissionScope



from abc import ABC
from dataclasses import dataclass


class PromptValue(ABC):
    pass


@dataclass
class StringPromptValue(PromptValue):
    text: str

    def to_string(self) -> str:
        return self.text



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/entities/entity_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.feature_store.entities import entity_pb2 as qwak_dot_feature__store_dot_entities_dot_entity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0qwak/feature_store/entities/entity_service.proto\x12\x1bqwak.feature.store.entities\x1a(qwak/feature_store/entities/entity.proto\"S\n\x13\x43reateEntityRequest\x12<\n\x0b\x65ntity_spec\x18\x01 \x01(\x0b\x32\'.qwak.feature.store.entities.EntitySpec\"f\n\x13UpdateEntityRequest\x12\x11\n\tentity_id\x18\x01 \x01(\t\x12<\n\x0b\x65ntity_spec\x18\x02 \x01(\x0b\x32\'.qwak.feature.store.entities.EntitySpec\"K\n\x14UpdateEntityResponse\x12\x33\n\x06\x65ntity\x18\x01 \x01(\x0b\x32#.qwak.feature.store.entities.Entity\"K\n\x14\x43reateEntityResponse\x12\x33\n\x06\x65ntity\x18\x01 \x01(\x0b\x32#.qwak.feature.store.entities.Entity\")\n\x14GetEntityByIdRequest\x12\x11\n\tentity_id\x18\x01 \x01(\t\"L\n\x15GetEntityByIdResponse\x12\x33\n\x06\x65ntity\x18\x01 \x01(\x0b\x32#.qwak.feature.store.entities.Entity\"-\n\x16GetEntityByNameRequest\x12\x13\n\x0b\x65ntity_name\x18\x01 \x01(\t\"N\n\x17GetEntityByNameResponse\x12\x33\n\x06\x65ntity\x18\x01 \x01(\x0b\x32#.qwak.feature.store.entities.Entity\"(\n\x13\x44\x65leteEntityRequest\x12\x11\n\tentity_id\x18\x01 \x01(\t\"\x16\n\x14\x44\x65leteEntityResponse\"\x15\n\x13ListEntitiesRequest\"M\n\x14ListEntitiesResponse\x12\x35\n\x08\x65ntities\x18\x01 \x03(\x0b\x32#.qwak.feature.store.entities.Entity2\xd9\x05\n\rEntityService\x12s\n\x0c\x43reateEntity\x12\x30.qwak.feature.store.entities.CreateEntityRequest\x1a\x31.qwak.feature.store.entities.CreateEntityResponse\x12s\n\x0cUpdateEntity\x12\x30.qwak.feature.store.entities.UpdateEntityRequest\x1a\x31.qwak.feature.store.entities.UpdateEntityResponse\x12s\n\x0c\x44\x65leteEntity\x12\x30.qwak.feature.store.entities.DeleteEntityRequest\x1a\x31.qwak.feature.store.entities.DeleteEntityResponse\x12v\n\rGetEntityById\x12\x31.qwak.feature.store.entities.GetEntityByIdRequest\x1a\x32.qwak.feature.store.entities.GetEntityByIdResponse\x12|\n\x0fGetEntityByName\x12\x33.qwak.feature.store.entities.GetEntityByNameRequest\x1a\x34.qwak.feature.store.entities.GetEntityByNameResponse\x12s\n\x0cListEntities\x12\x30.qwak.feature.store.entities.ListEntitiesRequest\x1a\x31.qwak.feature.store.entities.ListEntitiesResponseB]\n(com.qwak.ai.feature.store.management.apiP\x01Z/qwak/featurestore/entities;featurestoreentitiesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.entities.entity_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.qwak.ai.feature.store.management.apiP\001Z/qwak/featurestore/entities;featurestoreentities'
  _globals['_CREATEENTITYREQUEST']._serialized_start=123
  _globals['_CREATEENTITYREQUEST']._serialized_end=206
  _globals['_UPDATEENTITYREQUEST']._serialized_start=208
  _globals['_UPDATEENTITYREQUEST']._serialized_end=310
  _globals['_UPDATEENTITYRESPONSE']._serialized_start=312
  _globals['_UPDATEENTITYRESPONSE']._serialized_end=387
  _globals['_CREATEENTITYRESPONSE']._serialized_start=389
  _globals['_CREATEENTITYRESPONSE']._serialized_end=464
  _globals['_GETENTITYBYIDREQUEST']._serialized_start=466
  _globals['_GETENTITYBYIDREQUEST']._serialized_end=507
  _globals['_GETENTITYBYIDRESPONSE']._serialized_start=509
  _globals['_GETENTITYBYIDRESPONSE']._serialized_end=585
  _globals['_GETENTITYBYNAMEREQUEST']._serialized_start=587
  _globals['_GETENTITYBYNAMEREQUEST']._serialized_end=632
  _globals['_GETENTITYBYNAMERESPONSE']._serialized_start=634
  _globals['_GETENTITYBYNAMERESPONSE']._serialized_end=712
  _globals['_DELETEENTITYREQUEST']._serialized_start=714
  _globals['_DELETEENTITYREQUEST']._serialized_end=754
  _globals['_DELETEENTITYRESPONSE']._serialized_start=756
  _globals['_DELETEENTITYRESPONSE']._serialized_end=778
  _globals['_LISTENTITIESREQUEST']._serialized_start=780
  _globals['_LISTENTITIESREQUEST']._serialized_end=801
  _globals['_LISTENTITIESRESPONSE']._serialized_start=803
  _globals['_LISTENTITIESRESPONSE']._serialized_end=880
  _globals['_ENTITYSERVICE']._serialized_start=883
  _globals['_ENTITYSERVICE']._serialized_end=1612
# @@protoc_insertion_point(module_scope)



from __future__ import annotations

from typing import Dict, List, Optional

from _qwak_proto.qwak.vectors.v1.collection.collection_pb2 import (
    VectorCollectionDefinition,
    VectorCollectionMetric,
)
from qwak.clients.vector_store import VectorManagementClient, VectorServingClient
from qwak.exceptions import QwakException
from qwak.vector_store.collection import Collection
from typeguard import typechecked


class VectorStoreClient:
    """
    The `VectorStoreClient` class is designed to interact with Qwak's vector store service. A vector store is a
    specialized storage service optimized for storing and querying high-dimensional vectors. These vectors can be
    representations extracted from images, text, or any other type of data.
    Vector stores are often used in machine learning applications for operations such as nearest neighbor searches,
    similarity measures, and clustering.
    """

    _vector_management_client: VectorManagementClient

    _metric_dict: Dict[str, VectorCollectionMetric] = {
        "l2_squared": VectorCollectionMetric.COLLECTION_METRIC_L2_SQUARED,
        "cosine": VectorCollectionMetric.COLLECTION_METRIC_COSINE,
        "dot_product": VectorCollectionMetric.COLLECTION_METRIC_DOT_PRODUCT,
        "l1": VectorCollectionMetric.COLLECTION_METRIC_L1,
        "hamming": VectorCollectionMetric.COLLECTION_METRIC_HAMMING,
    }

    def __init__(self, edge_services_url: Optional[str] = None):
        """
        Initializes a `VectorStoreClient` client object to interact with Qwak's vector store service
        """
        self._vector_management_client = VectorManagementClient()
        self._vector_serving_client = VectorServingClient(
            edge_services_url=edge_services_url
        )

    @typechecked
    def create_collection(
        self,
        name: str,
        dimension: int,
        description: str = None,
        metric: str = "l2_squared",
        vectorizer: Optional[str] = None,
        multi_tenant: bool = False,
    ) -> Collection:
        """
        Creates a new collection with the given name and dimension.
        Each collection in the vector store can be thought of as a table or a namespace that holds vectors of a
        particular dimension. For example, you may have a collection named "image_embeddings" where each vector is of
        dimension 512, representing an embedding of an image.

        Parameters:
            name (str): The name of the collection to create.
            dimension (int): The dimension of the vectors in the collection.
            description (str, optional): A human-readable description of the collection.
            metric (int): The distance metric used by the collection when executing similarity search
            vectorizer (str): an optional Qwak model used for vector embedding in case natural input is provided
            multi_tenant (bool): Whether this collection has multitenancy. defaults to False and cannot be changed
                                after the collection is created

        Returns:
            Collection: The Collection object which is used to interact with the vector store.

        Raises:
            QwakException: if any of the collection creation parameters are invalid
        """
        proto_definition = self._vector_management_client.create_collection(
            name=name,
            description=description,
            dimension=dimension,
            metric=self._metrics_mapper(metric),
            vectorizer=vectorizer,
            multi_tenant=multi_tenant,
        ).definition

        return self._collection_from_definition(proto_definition)

    @typechecked
    def delete_collection(self, name: str) -> None:
        """
        Deletes a collection with the given name.

        Parameters:
            name (str): The name of the collection to delete.

        Raises:
            QwakException: in case the deletion failed for any reason
        """
        self._vector_management_client.delete_collection_by_name(name=name)

    @typechecked
    def get_collection_by_name(self, name: str) -> Collection:
        """
        Fetches a collection by its name.

        Parameters:
            name (str): The name of the collection to fetch.

        Returns:
            collection: a Collection object

        Raises:
            QwakException: in case the collection doesn't exist
        """
        proto_definition = self._vector_management_client.get_collection_by_name(
            name
        ).definition
        return self._collection_from_definition(proto_definition)

    def list_collections(self) -> List[Collection]:
        """
        Lists all available collections in the current Qwak account

         Returns:
             list: A list of Collection objects.
        """
        proto_definitions = self._vector_management_client.list_collections()
        return [
            self._collection_from_definition(collection.definition)
            for collection in proto_definitions
        ]

    def _collection_from_definition(
        self, collection_definition: VectorCollectionDefinition
    ):
        return Collection(
            id=collection_definition.id,
            name=collection_definition.collection_spec.name,
            metric=collection_definition.collection_spec.metric,
            dimension=collection_definition.collection_spec.dimension,
            description=collection_definition.collection_spec.description,
            vectorizer=collection_definition.collection_spec.vectorizer.qwak_model_name,
            vector_serving_client=self._vector_serving_client,
            muli_tenant=collection_definition.collection_spec.multi_tenancy_enabled,
        )

    def _metrics_mapper(self, metric: str) -> VectorCollectionMetric:
        if metric in self._metric_dict:
            return self._metric_dict[metric]

        raise QwakException(
            f"Unsupported metric type '{metric}'. Currently supported metrics are {list(self._metric_dict.keys())}"
        )



from abc import ABC, abstractmethod
from typing import Dict, List, Optional, Union

from frogml_storage.models.frogml_dataset_version import FrogMLDatasetVersion
from frogml_storage.models.frogml_model_version import FrogMLModelVersion
from frogml_storage.models.serialization_metadata import SerializationMetadata


class BaseStorage(ABC):
    """
    Repository storage to download or store model | dataset artifacts,
    metrics and relation between these in an Artifactory repository.
    """

    @abstractmethod
    def upload_model_version(
        self,
        repository: str,
        model_name: str,
        model_path: str,
        model_type: Union[SerializationMetadata, Dict],
        namespace: Optional[str] = None,
        version: Optional[str] = None,
        properties: Optional[dict[str, str]] = None,
        dependencies_files_paths: Optional[List[str]] = None,
        code_archive_file_path: Optional[str] = None,
    ) -> FrogMLModelVersion:
        """Upload model to a repository in Artifactory. Uploaded models should be stored with the following layout:
        ├── REPO
            ├── models
                ├── ${NAMESPACE}
                    ├── ${MODEL_NAME}
                        ├── ${MODEL_VERSION}
                            ├── model-manifest.json
                            ├── model
                                ├── model.pkl
                                ├── evidence.json
                                ├── ...
                            ├── code
                                ├── code.zip
                                ├── requirements.txt
        :param repository: the repository to upload the model to
        :param model_name: the name of the model
        :param model_path: the source path of the model
        :param model_type: the type of the model (PyTorch, HuggingFace, Catboost)
        :param namespace: the namespace to upload the model to
        :param version: the version of the model
        :param properties: tags to associate with the model
        :param dependencies_files_paths: the list of dependencies files paths
        :param code_archive_file_path: the path to the code archive file
        """
        pass

    @abstractmethod
    def download_model_version(
        self,
        repository: str,
        model_name: str,
        version: str,
        target_path: str,
        namespace: Optional[str] = None,
    ) -> None:
        """Downloads a model from an Artifactory repository
        :param repository: the repository to download the model from
        :param model_name: the name of the model to download
        :param version: the version of the model to download
        :param target_path: the target local path to store the model in
        :param namespace: the namespace of the model to download

        """
        pass

    def download_model_single_artifact(
        self,
        repository: str,
        model_name: str,
        version: str,
        target_path: str,
        source_artifact_path: str,
        namespace: Optional[str] = None,
    ) -> None:
        """Downloads an artifact from an Artifactory repository
        :param repository: the repository to download the artifact from
        :param model_name: the model to download artifact from
        :param version: the model's version to download artifact from
        :param target_path: the target local path to store the artifact in
        :param source_artifact_path: the path of the artifact under the model's version directory
        :param namespace: the namespace of the artifact
        """
        pass

    @abstractmethod
    def upload_dataset_version(
        self,
        repository: str,
        dataset_name: str,
        source_path: str,
        namespace: Optional[str] = None,
        version: Optional[str] = None,
        tags: Optional[dict[str, str]] = None,
    ) -> FrogMLDatasetVersion:
        """Uploads a dataset to a repository in Artifactory. Uploaded datasets should be stored with
         the following layout:
        ├── REPO
            ├── datasets
                ├── ${NAMESPACE}
                    ├── ${DATASET_NAME}
                        ├── ${DATASET_VERSION}
                            ├── dataset-manifest.json
                            ├── dataset
                                ├── cli_docs_1.csv
                                ├── cli_docs_2.csv
                                ├── ...
        :param repository: the repository to upload the dataset to
        :param dataset_name: the name of the dataset
        :param source_path: the source path of the dataset
        :param namespace: the namespace to upload the dataset to
        :param version: the version of the dataset
        :param tags: tags to associate with the dataset
        """
        pass

    @abstractmethod
    def download_dataset_version(
        self,
        repository: str,
        dataset_name: str,
        version: str,
        target_path: str,
        namespace: Optional[str] = None,
    ) -> None:
        """Downloads a dataset from an Artifactory repository
        :param repository: the repository to download the dataset from
        :param dataset_name: the name of the dataset to download
        :param version: the version of the dataset to download
        :param target_path: the target local path to store the dataset in
        :param namespace: the namespace of the dataset to download

        """
        pass



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/batch_job/v1/batch_job_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.user_application.common.v0 import resources_pb2 as qwak_dot_user__application_dot_common_dot_v0_dot_resources__pb2
from _qwak_proto.qwak.batch_job.v1 import batch_job_events_pb2 as qwak_dot_batch__job_dot_v1_dot_batch__job__events__pb2
from _qwak_proto.qwak.administration.authenticated_user.v1 import credentials_pb2 as qwak_dot_administration_dot_authenticated__user_dot_v1_dot_credentials__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)qwak/batch_job/v1/batch_job_service.proto\x12\rqwak.batchjob\x1a\x1fgoogle/protobuf/timestamp.proto\x1a/qwak/user_application/common/v0/resources.proto\x1a(qwak/batch_job/v1/batch_job_events.proto\x1a;qwak/administration/authenticated_user/v1/credentials.proto\"\xb4\x01\n\x15StartWarmupJobRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x62uild_id\x18\x05 \x01(\t\x12\x16\n\x0ewarmup_timeout\x18\x03 \x01(\x05\x12H\n\x19\x62\x61tch_job_deployment_size\x18\x04 \x01(\x0b\x32%.qwak.batchjob.BatchJobDeploymentSize\"B\n\x16StartWarmupJobResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x02 \x01(\t\"S\n\x16\x43\x61ncelWarmupJobRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x62uild_id\x18\x03 \x01(\t\"C\n\x17\x43\x61ncelWarmupJobResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x02 \x01(\t\"\x89\x05\n\x14StartBatchJobRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x62uild_id\x18\x0f \x01(\t\x12\x15\n\rsource_bucket\x18\x03 \x01(\t\x12\x1a\n\x12\x64\x65stination_bucket\x18\x04 \x01(\t\x12\x15\n\rsource_folder\x18\x05 \x01(\t\x12\x1a\n\x12\x64\x65stination_folder\x18\x06 \x01(\t\x12H\n\x19\x62\x61tch_job_deployment_size\x18\x07 \x01(\x0b\x32%.qwak.batchjob.BatchJobDeploymentSize\x12\x13\n\x0bjob_timeout\x18\x08 \x01(\x05\x12\x14\n\x0ctask_timeout\x18\t \x01(\x05\x12\x35\n\x0finput_file_type\x18\n \x01(\x0e\x32\x1c.qwak.batchjob.InputFileType\x12\x37\n\x10output_file_type\x18\x0b \x01(\x0e\x32\x1d.qwak.batchjob.OutputFileType\x12\x14\n\x0ctoken_secret\x18\x0c \x01(\t\x12\x15\n\rsecret_secret\x18\r \x01(\t\x12M\n\x1b\x61\x64vanced_deployment_options\x18\x0e \x01(\x0b\x32(.qwak.batchjob.AdvancedDeploymentOptions\x12\x34\n\nparameters\x18\x10 \x03(\x0b\x32 .qwak.batchjob.BatchJobParameter\x12\x39\n\x11\x62\x61tch_job_request\x18\x11 \x01(\x0b\x32\x1e.qwak.batchjob.BatchJobRequest\"\xcb\x01\n\x0f\x42\x61tchJobRequest\x12:\n\rmodel_details\x18\x01 \x01(\x0b\x32#.qwak.batchjob.BatchJobModelDetails\x12\x38\n\x0c\x64\x61ta_details\x18\x02 \x01(\x0b\x32\".qwak.batchjob.BatchJobDataDetails\x12\x42\n\x11\x65xecution_details\x18\x04 \x01(\x0b\x32\'.qwak.batchjob.BatchJobExecutionDetails\":\n\x14\x42\x61tchJobModelDetails\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x0f \x01(\t\"\xe5\x01\n\x13\x42\x61tchJobDataDetails\x12\x36\n\x0bsource_path\x18\x01 \x01(\x0b\x32!.qwak.batchjob.BatchJobSourcePath\x12@\n\x10\x64\x65stination_path\x18\x02 \x01(\x0b\x32&.qwak.batchjob.BatchJobDestinationPath\x12\x14\n\x0ctoken_secret\x18\x0c \x01(\t\x12\x15\n\rsecret_secret\x18\r \x01(\t\x12\'\n\x1fservice_account_json_key_secret\x18\x05 \x01(\t\"y\n\x12\x42\x61tchJobSourcePath\x12\x15\n\rsource_bucket\x18\x01 \x01(\t\x12\x15\n\rsource_folder\x18\x02 \x01(\t\x12\x35\n\x0finput_file_type\x18\x03 \x01(\x0e\x32\x1c.qwak.batchjob.InputFileType\"\x8a\x01\n\x17\x42\x61tchJobDestinationPath\x12\x1a\n\x12\x64\x65stination_bucket\x18\x01 \x01(\t\x12\x1a\n\x12\x64\x65stination_folder\x18\x02 \x01(\t\x12\x37\n\x10output_file_type\x18\x03 \x01(\x0e\x32\x1d.qwak.batchjob.OutputFileType\"\x94\x02\n\x18\x42\x61tchJobExecutionDetails\x12\x13\n\x0bjob_timeout\x18\x01 \x01(\x05\x12\x14\n\x0ctask_timeout\x18\x02 \x01(\x05\x12H\n\x19\x62\x61tch_job_deployment_size\x18\x03 \x01(\x0b\x32%.qwak.batchjob.BatchJobDeploymentSize\x12M\n\x1b\x61\x64vanced_deployment_options\x18\x04 \x01(\x0b\x32(.qwak.batchjob.AdvancedDeploymentOptions\x12\x34\n\nparameters\x18\x05 \x03(\x0b\x32 .qwak.batchjob.BatchJobParameter\"/\n\x11\x42\x61tchJobParameter\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"S\n\x15StartBatchJobResponse\x12\x10\n\x08\x62\x61tch_id\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x03 \x01(\t\")\n\x15\x43\x61ncelBatchJobRequest\x12\x10\n\x08\x62\x61tch_id\x18\x01 \x01(\t\"B\n\x16\x43\x61ncelBatchJobResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x02 \x01(\t\",\n\x18GetBatchJobStatusRequest\x12\x10\n\x08\x62\x61tch_id\x18\x01 \x01(\t\"\xac\x01\n\x19GetBatchJobStatusResponse\x12\x38\n\njob_status\x18\x01 \x01(\x0e\x32$.qwak.batchjob.BatchJobStatusMessage\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x03 \x01(\t\x12\x16\n\x0e\x66inished_files\x18\x04 \x01(\x05\x12\x13\n\x0btotal_files\x18\x05 \x01(\x05\",\n\x18GetBatchJobReportRequest\x12\x10\n\x08\x62\x61tch_id\x18\x01 \x01(\t\"a\n\x19GetBatchJobReportResponse\x12\x12\n\nsuccessful\x18\x01 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x02 \x01(\t\x12\x17\n\x0freport_messages\x18\x03 \x03(\t\"`\n\x1dUpdateBatchTasksStatusRequest\x12?\n\x11\x62\x61tch_task_events\x18\x01 \x03(\x0b\x32$.qwak.batchjob.BatchTaskEventMessage\"I\n\x1dUpdateBatchTaskStatusResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x02 \x01(\t\"z\n\x19\x41\x64vancedDeploymentOptions\x12\x1b\n\x13\x63ustom_iam_role_arn\x18\x01 \x01(\t\x12\x17\n\x0fpurchase_option\x18\x02 \x01(\t\x12\'\n\x1fservice_account_key_secret_name\x18\x03 \x01(\t\"\x85\x03\n\x16\x42\x61tchJobDeploymentSize\x12\x16\n\x0enumber_of_pods\x18\x01 \x01(\x05\x12\x0f\n\x03\x63pu\x18\x02 \x01(\x02\x42\x02\x18\x01\x12\x19\n\rmemory_amount\x18\x03 \x01(\x05\x42\x02\x18\x01\x12J\n\x0cmemory_units\x18\x04 \x01(\x0e\x32\x30.qwak.batchjob.BatchJobDeploymentSize.MemoryUnitB\x02\x18\x01\x12H\n\rgpu_resources\x18\x05 \x01(\x0b\x32-.qwak.user_application.common.v0.GpuResourcesB\x02\x18\x01\x12`\n\x1c\x63lient_pod_compute_resources\x18\x06 \x01(\x0b\x32:.qwak.user_application.common.v0.ClientPodComputeResources\"/\n\nMemoryUnit\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03MIB\x10\x01\x12\x07\n\x03GIB\x10\x02\x1a\x02\x18\x01\"\x99\x01\n\x15\x42\x61tchJobExecutionSize\x12\x16\n\x0enumber_of_pods\x18\x01 \x01(\x05\x12S\n\x15pod_compute_resources\x18\x02 \x01(\x0b\x32\x34.qwak.user_application.common.v0.PodComputeResources\x12\x13\n\x0btemplate_id\x18\x03 \x01(\t\"Q\n\x14ListBatchJobsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x62uild_id\x18\x03 \x01(\t\"K\n\x15ListBatchJobsResponse\x12\x32\n\nbatch_jobs\x18\x01 \x03(\x0b\x32\x1e.qwak.batchjob.BatchJobDetails\"\x81\x03\n\x0f\x42\x61tchJobDetails\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\t\x12\x38\n\njob_status\x18\x03 \x01(\x0e\x32$.qwak.batchjob.BatchJobStatusMessage\x12.\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0f\x66\x61ilure_message\x18\x06 \x01(\t\x12;\n\x08job_size\x18\x07 \x01(\x0b\x32%.qwak.batchjob.BatchJobDeploymentSizeB\x02\x18\x01\x12\x46\n\x18\x62\x61tch_job_execution_size\x18\x08 \x01(\x0b\x32$.qwak.batchjob.BatchJobExecutionSize\x12\x16\n\x0e\x65nvironment_id\x18\t \x01(\t\"+\n\x19GetBatchJobDetailsRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"y\n\x1aGetBatchJobDetailsResponse\x12\x31\n\tbatch_job\x18\x01 \x01(\x0b\x32\x1e.qwak.batchjob.BatchJobMessage\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x03 \x01(\t\"\x84\x04\n\x0f\x42\x61tchJobMessage\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x15\n\tbranch_id\x18\x03 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x62uild_id\x18\x04 \x01(\t\x12.\n\nstart_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\njob_status\x18\x07 \x01(\x0e\x32$.qwak.batchjob.BatchJobStatusMessage\x12\x15\n\rtotal_records\x18\x08 \x01(\x05\x12\x37\n\x08job_size\x18\t \x01(\x0b\x32%.qwak.batchjob.BatchJobDeploymentSize\x12;\n\x0freport_messages\x18\n \x03(\x0b\x32\".qwak.batchjob.ExecutionReportLine\x12\x43\n\x16\x65xecution_file_details\x18\x0b \x01(\x0b\x32#.qwak.batchjob.ExecutionFileDetails\x12<\n\x0ftask_executions\x18\x0c \x03(\x0b\x32#.qwak.batchjob.TaskExecutionDetails\"M\n\x13\x45xecutionReportLine\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04line\x18\x02 \x01(\t\"\x95\x02\n\x14\x45xecutionFileDetails\x12\x15\n\rsource_bucket\x18\x01 \x01(\t\x12\x1a\n\x12\x64\x65stination_bucket\x18\x02 \x01(\t\x12\x13\n\x0bsource_path\x18\x03 \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x04 \x01(\t\x12\x35\n\x0finput_file_type\x18\x05 \x01(\x0e\x32\x1c.qwak.batchjob.InputFileType\x12\x37\n\x10output_file_type\x18\x06 \x01(\x0e\x32\x1d.qwak.batchjob.OutputFileType\x12\x16\n\x0e\x66inished_files\x18\x07 \x01(\x05\x12\x13\n\x0btotal_files\x18\x08 \x01(\x05\"\xfd\x01\n\x14TaskExecutionDetails\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x35\n\x06status\x18\x02 \x01(\x0e\x32%.qwak.batchjob.BatchTaskStatusMessage\x12.\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0enum_of_records\x18\x05 \x01(\x05\x12\x14\n\x08\x66ilename\x18\x06 \x01(\tB\x02\x18\x01\x12\x11\n\tfilenames\x18\x07 \x03(\t\"d\n$GetBatchJobPreSignedUploadUrlRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x17\n\x0fnumber_of_files\x18\x02 \x01(\x05\x12\x11\n\tfile_type\x18\x03 \x01(\t\"\x98\x01\n%GetBatchJobPreSignedUploadUrlResponse\x12\x12\n\ninput_path\x18\x01 \x01(\t\x12\x13\n\x0boutput_path\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x0c\n\x04urls\x18\x04 \x03(\t\x12\x0f\n\x07success\x18\x05 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x06 \x01(\t\"8\n&GetBatchJobPreSignedDownloadUrlRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"a\n\'GetBatchJobPreSignedDownloadUrlResponse\x12\x0c\n\x04urls\x18\x01 \x03(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x03 \x01(\t\"3\n\x1fGetBatchJobUploadDetailsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\"\xb4\x01\n GetBatchJobUploadDetailsResponse\x12\x12\n\ninput_path\x18\x01 \x01(\t\x12\x13\n\x0boutput_path\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12W\n\x0b\x63redentials\x18\x04 \x01(\x0b\x32\x42.qwak.administration.authenticated_user.v1.AwsTemporaryCredentials\"3\n!GetBatchJobDownloadDetailsRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\x9b\x01\n\"GetBatchJobDownloadDetailsResponse\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12W\n\x0b\x63redentials\x18\x03 \x01(\x0b\x32\x42.qwak.administration.authenticated_user.v1.AwsTemporaryCredentials\"\xd7\x01\n\x1aUpdateDefaultParamsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\x12\x46\n\x17\x64\x65\x66\x61ult_deployment_size\x18\x03 \x01(\x0b\x32%.qwak.batchjob.BatchJobDeploymentSize\x12M\n\x1b\x61\x64vanced_deployment_options\x18\x04 \x01(\x0b\x32(.qwak.batchjob.AdvancedDeploymentOptions\"\x1d\n\x1bUpdateDefaultParamsResponse\".\n\x1a\x44\x65leteDefaultParamsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\"\x1d\n\x1b\x44\x65leteDefaultParamsResponse\"S\n&UpdateTaskIngestedRecordsAmountRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x18\n\x10ingested_records\x18\x02 \x01(\x03\")\n\'UpdateTaskIngestedRecordsAmountResponse\"S\n\x19UpdateTasksDetailsRequest\x12\x36\n\rtasks_details\x18\x01 \x03(\x0b\x32\x1f.qwak.batchjob.BatchTaskDetails\"\x1c\n\x1aUpdateTasksDetailsResponse\"a\n\x10\x42\x61tchTaskDetails\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12<\n\x13input_files_details\x18\x02 \x03(\x0b\x32\x1f.qwak.batchjob.InputFileDetails\" \n\x10InputFileDetails\x12\x0c\n\x04path\x18\x01 \x01(\t*\x81\x01\n\rInputFileType\x12\x1d\n\x19UNDEFINED_INPUT_FILE_TYPE\x10\x00\x12\x17\n\x13\x43SV_INPUT_FILE_TYPE\x10\x01\x12\x1b\n\x17\x46\x45\x41THER_INPUT_FILE_TYPE\x10\x02\x12\x1b\n\x17PARQUET_INPUT_FILE_TYPE\x10\x03*\x86\x01\n\x0eOutputFileType\x12\x1e\n\x1aUNDEFINED_OUTPUT_FILE_TYPE\x10\x00\x12\x18\n\x14\x43SV_OUTPUT_FILE_TYPE\x10\x01\x12\x1c\n\x18\x46\x45\x41THER_OUTPUT_FILE_TYPE\x10\x02\x12\x1c\n\x18PARQUET_OUTPUT_FILE_TYPE\x10\x03*\x8d\x02\n\x15\x42\x61tchJobStatusMessage\x12\x1e\n\x1aUNDEFINED_BATCH_JOB_STATUS\x10\x00\x12\x1e\n\x1a\x42\x41TCH_JOB_COMMITTED_STATUS\x10\x01\x12\x1c\n\x18\x42\x41TCH_JOB_PENDING_STATUS\x10\x02\x12\x1c\n\x18\x42\x41TCH_JOB_RUNNING_STATUS\x10\x03\x12\x1d\n\x19\x42\x41TCH_JOB_FINISHED_STATUS\x10\x04\x12\x1b\n\x17\x42\x41TCH_JOB_FAILED_STATUS\x10\x05\x12\x1e\n\x1a\x42\x41TCH_JOB_CANCELLED_STATUS\x10\x06\x12\x1c\n\x18\x42\x41TCH_JOB_TIMEOUT_STATUS\x10\x07*\x9c\x02\n\x16\x42\x61tchTaskStatusMessage\x12\x1f\n\x1bUNDEFINED_BATCH_TASK_STATUS\x10\x00\x12\x1f\n\x1b\x42\x41TCH_TASK_COMMITTED_STATUS\x10\x01\x12#\n\x1f\x42\x41TCH_TASK_PENDING_START_STATUS\x10\x02\x12\x1d\n\x19\x42\x41TCH_TASK_RUNNING_STATUS\x10\x03\x12\x1e\n\x1a\x42\x41TCH_TASK_FINISHED_STATUS\x10\x04\x12\x1c\n\x18\x42\x41TCH_TASK_FAILED_STATUS\x10\x05\x12\x1f\n\x1b\x42\x41TCH_TASK_CANCELLED_STATUS\x10\x06\x12\x1d\n\x19\x42\x41TCH_TASK_TIMEOUT_STATUS\x10\x07\x32\x9f\x0f\n\x19\x42\x61tchJobManagementService\x12Z\n\rStartBatchJob\x12#.qwak.batchjob.StartBatchJobRequest\x1a$.qwak.batchjob.StartBatchJobResponse\x12]\n\x0e\x43\x61ncelBatchJob\x12$.qwak.batchjob.CancelBatchJobRequest\x1a%.qwak.batchjob.CancelBatchJobResponse\x12]\n\x0eStartWarmupJob\x12$.qwak.batchjob.StartWarmupJobRequest\x1a%.qwak.batchjob.StartWarmupJobResponse\x12`\n\x0f\x43\x61ncelWarmupJob\x12%.qwak.batchjob.CancelWarmupJobRequest\x1a&.qwak.batchjob.CancelWarmupJobResponse\x12\x66\n\x11GetBatchJobStatus\x12\'.qwak.batchjob.GetBatchJobStatusRequest\x1a(.qwak.batchjob.GetBatchJobStatusResponse\x12\x66\n\x11GetBatchJobReport\x12\'.qwak.batchjob.GetBatchJobReportRequest\x1a(.qwak.batchjob.GetBatchJobReportResponse\x12t\n\x16UpdateBatchTasksStatus\x12,.qwak.batchjob.UpdateBatchTasksStatusRequest\x1a,.qwak.batchjob.UpdateBatchTaskStatusResponse\x12Z\n\rListBatchJobs\x12#.qwak.batchjob.ListBatchJobsRequest\x1a$.qwak.batchjob.ListBatchJobsResponse\x12i\n\x12GetBatchJobDetails\x12(.qwak.batchjob.GetBatchJobDetailsRequest\x1a).qwak.batchjob.GetBatchJobDetailsResponse\x12\x8a\x01\n\x1dGetBatchJobPreSignedUploadUrl\x12\x33.qwak.batchjob.GetBatchJobPreSignedUploadUrlRequest\x1a\x34.qwak.batchjob.GetBatchJobPreSignedUploadUrlResponse\x12\x90\x01\n\x1fGetBatchJobPreSignedDownloadUrl\x12\x35.qwak.batchjob.GetBatchJobPreSignedDownloadUrlRequest\x1a\x36.qwak.batchjob.GetBatchJobPreSignedDownloadUrlResponse\x12{\n\x18GetBatchJobUploadDetails\x12..qwak.batchjob.GetBatchJobUploadDetailsRequest\x1a/.qwak.batchjob.GetBatchJobUploadDetailsResponse\x12\x81\x01\n\x1aGetBatchJobDownloadDetails\x12\x30.qwak.batchjob.GetBatchJobDownloadDetailsRequest\x1a\x31.qwak.batchjob.GetBatchJobDownloadDetailsResponse\x12l\n\x13UpdateDefaultParams\x12).qwak.batchjob.UpdateDefaultParamsRequest\x1a*.qwak.batchjob.UpdateDefaultParamsResponse\x12l\n\x13\x44\x65leteDefaultParams\x12).qwak.batchjob.DeleteDefaultParamsRequest\x1a*.qwak.batchjob.DeleteDefaultParamsResponse\x12\x90\x01\n\x1fUpdateTaskIngestedRecordsAmount\x12\x35.qwak.batchjob.UpdateTaskIngestedRecordsAmountRequest\x1a\x36.qwak.batchjob.UpdateTaskIngestedRecordsAmountResponse\x12i\n\x12UpdateTasksDetails\x12(.qwak.batchjob.UpdateTasksDetailsRequest\x1a).qwak.batchjob.UpdateTasksDetailsResponseB.\n\x19\x63om.qwak.ai.batch.job.apiP\x01Z\x0f./;inferencejobb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.batch_job.v1.batch_job_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.qwak.ai.batch.job.apiP\001Z\017./;inferencejob'
  _STARTWARMUPJOBREQUEST.fields_by_name['branch_id']._options = None
  _STARTWARMUPJOBREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _CANCELWARMUPJOBREQUEST.fields_by_name['branch_id']._options = None
  _CANCELWARMUPJOBREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _STARTBATCHJOBREQUEST.fields_by_name['branch_id']._options = None
  _STARTBATCHJOBREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _BATCHJOBDEPLOYMENTSIZE_MEMORYUNIT._options = None
  _BATCHJOBDEPLOYMENTSIZE_MEMORYUNIT._serialized_options = b'\030\001'
  _BATCHJOBDEPLOYMENTSIZE.fields_by_name['cpu']._options = None
  _BATCHJOBDEPLOYMENTSIZE.fields_by_name['cpu']._serialized_options = b'\030\001'
  _BATCHJOBDEPLOYMENTSIZE.fields_by_name['memory_amount']._options = None
  _BATCHJOBDEPLOYMENTSIZE.fields_by_name['memory_amount']._serialized_options = b'\030\001'
  _BATCHJOBDEPLOYMENTSIZE.fields_by_name['memory_units']._options = None
  _BATCHJOBDEPLOYMENTSIZE.fields_by_name['memory_units']._serialized_options = b'\030\001'
  _BATCHJOBDEPLOYMENTSIZE.fields_by_name['gpu_resources']._options = None
  _BATCHJOBDEPLOYMENTSIZE.fields_by_name['gpu_resources']._serialized_options = b'\030\001'
  _LISTBATCHJOBSREQUEST.fields_by_name['branch_id']._options = None
  _LISTBATCHJOBSREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _BATCHJOBDETAILS.fields_by_name['job_size']._options = None
  _BATCHJOBDETAILS.fields_by_name['job_size']._serialized_options = b'\030\001'
  _BATCHJOBMESSAGE.fields_by_name['branch_id']._options = None
  _BATCHJOBMESSAGE.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _TASKEXECUTIONDETAILS.fields_by_name['filename']._options = None
  _TASKEXECUTIONDETAILS.fields_by_name['filename']._serialized_options = b'\030\001'
  _globals['_INPUTFILETYPE']._serialized_start=7215
  _globals['_INPUTFILETYPE']._serialized_end=7344
  _globals['_OUTPUTFILETYPE']._serialized_start=7347
  _globals['_OUTPUTFILETYPE']._serialized_end=7481
  _globals['_BATCHJOBSTATUSMESSAGE']._serialized_start=7484
  _globals['_BATCHJOBSTATUSMESSAGE']._serialized_end=7753
  _globals['_BATCHTASKSTATUSMESSAGE']._serialized_start=7756
  _globals['_BATCHTASKSTATUSMESSAGE']._serialized_end=8040
  _globals['_STARTWARMUPJOBREQUEST']._serialized_start=246
  _globals['_STARTWARMUPJOBREQUEST']._serialized_end=426
  _globals['_STARTWARMUPJOBRESPONSE']._serialized_start=428
  _globals['_STARTWARMUPJOBRESPONSE']._serialized_end=494
  _globals['_CANCELWARMUPJOBREQUEST']._serialized_start=496
  _globals['_CANCELWARMUPJOBREQUEST']._serialized_end=579
  _globals['_CANCELWARMUPJOBRESPONSE']._serialized_start=581
  _globals['_CANCELWARMUPJOBRESPONSE']._serialized_end=648
  _globals['_STARTBATCHJOBREQUEST']._serialized_start=651
  _globals['_STARTBATCHJOBREQUEST']._serialized_end=1300
  _globals['_BATCHJOBREQUEST']._serialized_start=1303
  _globals['_BATCHJOBREQUEST']._serialized_end=1506
  _globals['_BATCHJOBMODELDETAILS']._serialized_start=1508
  _globals['_BATCHJOBMODELDETAILS']._serialized_end=1566
  _globals['_BATCHJOBDATADETAILS']._serialized_start=1569
  _globals['_BATCHJOBDATADETAILS']._serialized_end=1798
  _globals['_BATCHJOBSOURCEPATH']._serialized_start=1800
  _globals['_BATCHJOBSOURCEPATH']._serialized_end=1921
  _globals['_BATCHJOBDESTINATIONPATH']._serialized_start=1924
  _globals['_BATCHJOBDESTINATIONPATH']._serialized_end=2062
  _globals['_BATCHJOBEXECUTIONDETAILS']._serialized_start=2065
  _globals['_BATCHJOBEXECUTIONDETAILS']._serialized_end=2341
  _globals['_BATCHJOBPARAMETER']._serialized_start=2343
  _globals['_BATCHJOBPARAMETER']._serialized_end=2390
  _globals['_STARTBATCHJOBRESPONSE']._serialized_start=2392
  _globals['_STARTBATCHJOBRESPONSE']._serialized_end=2475
  _globals['_CANCELBATCHJOBREQUEST']._serialized_start=2477
  _globals['_CANCELBATCHJOBREQUEST']._serialized_end=2518
  _globals['_CANCELBATCHJOBRESPONSE']._serialized_start=2520
  _globals['_CANCELBATCHJOBRESPONSE']._serialized_end=2586
  _globals['_GETBATCHJOBSTATUSREQUEST']._serialized_start=2588
  _globals['_GETBATCHJOBSTATUSREQUEST']._serialized_end=2632
  _globals['_GETBATCHJOBSTATUSRESPONSE']._serialized_start=2635
  _globals['_GETBATCHJOBSTATUSRESPONSE']._serialized_end=2807
  _globals['_GETBATCHJOBREPORTREQUEST']._serialized_start=2809
  _globals['_GETBATCHJOBREPORTREQUEST']._serialized_end=2853
  _globals['_GETBATCHJOBREPORTRESPONSE']._serialized_start=2855
  _globals['_GETBATCHJOBREPORTRESPONSE']._serialized_end=2952
  _globals['_UPDATEBATCHTASKSSTATUSREQUEST']._serialized_start=2954
  _globals['_UPDATEBATCHTASKSSTATUSREQUEST']._serialized_end=3050
  _globals['_UPDATEBATCHTASKSTATUSRESPONSE']._serialized_start=3052
  _globals['_UPDATEBATCHTASKSTATUSRESPONSE']._serialized_end=3125
  _globals['_ADVANCEDDEPLOYMENTOPTIONS']._serialized_start=3127
  _globals['_ADVANCEDDEPLOYMENTOPTIONS']._serialized_end=3249
  _globals['_BATCHJOBDEPLOYMENTSIZE']._serialized_start=3252
  _globals['_BATCHJOBDEPLOYMENTSIZE']._serialized_end=3641
  _globals['_BATCHJOBDEPLOYMENTSIZE_MEMORYUNIT']._serialized_start=3594
  _globals['_BATCHJOBDEPLOYMENTSIZE_MEMORYUNIT']._serialized_end=3641
  _globals['_BATCHJOBEXECUTIONSIZE']._serialized_start=3644
  _globals['_BATCHJOBEXECUTIONSIZE']._serialized_end=3797
  _globals['_LISTBATCHJOBSREQUEST']._serialized_start=3799
  _globals['_LISTBATCHJOBSREQUEST']._serialized_end=3880
  _globals['_LISTBATCHJOBSRESPONSE']._serialized_start=3882
  _globals['_LISTBATCHJOBSRESPONSE']._serialized_end=3957
  _globals['_BATCHJOBDETAILS']._serialized_start=3960
  _globals['_BATCHJOBDETAILS']._serialized_end=4345
  _globals['_GETBATCHJOBDETAILSREQUEST']._serialized_start=4347
  _globals['_GETBATCHJOBDETAILSREQUEST']._serialized_end=4390
  _globals['_GETBATCHJOBDETAILSRESPONSE']._serialized_start=4392
  _globals['_GETBATCHJOBDETAILSRESPONSE']._serialized_end=4513
  _globals['_BATCHJOBMESSAGE']._serialized_start=4516
  _globals['_BATCHJOBMESSAGE']._serialized_end=5032
  _globals['_EXECUTIONREPORTLINE']._serialized_start=5034
  _globals['_EXECUTIONREPORTLINE']._serialized_end=5111
  _globals['_EXECUTIONFILEDETAILS']._serialized_start=5114
  _globals['_EXECUTIONFILEDETAILS']._serialized_end=5391
  _globals['_TASKEXECUTIONDETAILS']._serialized_start=5394
  _globals['_TASKEXECUTIONDETAILS']._serialized_end=5647
  _globals['_GETBATCHJOBPRESIGNEDUPLOADURLREQUEST']._serialized_start=5649
  _globals['_GETBATCHJOBPRESIGNEDUPLOADURLREQUEST']._serialized_end=5749
  _globals['_GETBATCHJOBPRESIGNEDUPLOADURLRESPONSE']._serialized_start=5752
  _globals['_GETBATCHJOBPRESIGNEDUPLOADURLRESPONSE']._serialized_end=5904
  _globals['_GETBATCHJOBPRESIGNEDDOWNLOADURLREQUEST']._serialized_start=5906
  _globals['_GETBATCHJOBPRESIGNEDDOWNLOADURLREQUEST']._serialized_end=5962
  _globals['_GETBATCHJOBPRESIGNEDDOWNLOADURLRESPONSE']._serialized_start=5964
  _globals['_GETBATCHJOBPRESIGNEDDOWNLOADURLRESPONSE']._serialized_end=6061
  _globals['_GETBATCHJOBUPLOADDETAILSREQUEST']._serialized_start=6063
  _globals['_GETBATCHJOBUPLOADDETAILSREQUEST']._serialized_end=6114
  _globals['_GETBATCHJOBUPLOADDETAILSRESPONSE']._serialized_start=6117
  _globals['_GETBATCHJOBUPLOADDETAILSRESPONSE']._serialized_end=6297
  _globals['_GETBATCHJOBDOWNLOADDETAILSREQUEST']._serialized_start=6299
  _globals['_GETBATCHJOBDOWNLOADDETAILSREQUEST']._serialized_end=6350
  _globals['_GETBATCHJOBDOWNLOADDETAILSRESPONSE']._serialized_start=6353
  _globals['_GETBATCHJOBDOWNLOADDETAILSRESPONSE']._serialized_end=6508
  _globals['_UPDATEDEFAULTPARAMSREQUEST']._serialized_start=6511
  _globals['_UPDATEDEFAULTPARAMSREQUEST']._serialized_end=6726
  _globals['_UPDATEDEFAULTPARAMSRESPONSE']._serialized_start=6728
  _globals['_UPDATEDEFAULTPARAMSRESPONSE']._serialized_end=6757
  _globals['_DELETEDEFAULTPARAMSREQUEST']._serialized_start=6759
  _globals['_DELETEDEFAULTPARAMSREQUEST']._serialized_end=6805
  _globals['_DELETEDEFAULTPARAMSRESPONSE']._serialized_start=6807
  _globals['_DELETEDEFAULTPARAMSRESPONSE']._serialized_end=6836
  _globals['_UPDATETASKINGESTEDRECORDSAMOUNTREQUEST']._serialized_start=6838
  _globals['_UPDATETASKINGESTEDRECORDSAMOUNTREQUEST']._serialized_end=6921
  _globals['_UPDATETASKINGESTEDRECORDSAMOUNTRESPONSE']._serialized_start=6923
  _globals['_UPDATETASKINGESTEDRECORDSAMOUNTRESPONSE']._serialized_end=6964
  _globals['_UPDATETASKSDETAILSREQUEST']._serialized_start=6966
  _globals['_UPDATETASKSDETAILSREQUEST']._serialized_end=7049
  _globals['_UPDATETASKSDETAILSRESPONSE']._serialized_start=7051
  _globals['_UPDATETASKSDETAILSRESPONSE']._serialized_end=7079
  _globals['_BATCHTASKDETAILS']._serialized_start=7081
  _globals['_BATCHTASKDETAILS']._serialized_end=7178
  _globals['_INPUTFILEDETAILS']._serialized_start=7180
  _globals['_INPUTFILEDETAILS']._serialized_end=7212
  _globals['_BATCHJOBMANAGEMENTSERVICE']._serialized_start=8043
  _globals['_BATCHJOBMANAGEMENTSERVICE']._serialized_end=9994
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/model_descriptor/open_ai_descriptor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.qwak/model_descriptor/open_ai_descriptor.proto\x12#qwak.llmops.model_descriptor.openai\x1a\x1cgoogle/protobuf/struct.proto\"f\n\x18OpenAIProviderDescriptor\x12J\n\x06models\x18\x01 \x03(\x0b\x32:.qwak.llmops.model_descriptor.openai.OpenAIModelDescriptor\"x\n\x15OpenAIModelDescriptor\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12M\n\x0c\x63\x61pabilities\x18\x02 \x01(\x0b\x32\x37.qwak.llmops.model_descriptor.openai.OpenAICapabilities\"\xaf\x06\n\x15OpenAIChatModelParams\x12\x1b\n\x11\x66requency_penalty\x18\x01 \x01(\x01H\x00\x12-\n\nlogit_bias\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructH\x01\x12\x12\n\x08logprobs\x18\x03 \x01(\x08H\x02\x12\x14\n\nmax_tokens\x18\x04 \x01(\x03H\x03\x12\x0b\n\x01n\x18\x05 \x01(\x05H\x04\x12\x1a\n\x10presence_penalty\x18\x06 \x01(\x01H\x05\x12\x19\n\x0fresponse_format\x18\x07 \x01(\tH\x06\x12\x0e\n\x04seed\x18\x08 \x01(\x05H\x07\x12*\n\x04stop\x18\t \x01(\x0b\x32\x1a.google.protobuf.ListValueH\x08\x12\x15\n\x0btemperature\x18\n \x01(\x01H\t\x12\x46\n\x0btool_choice\x18\x0b \x01(\x0b\x32/.qwak.llmops.model_descriptor.openai.ToolChoiceH\n\x12@\n\ntools_spec\x18\x0c \x01(\x0b\x32*.qwak.llmops.model_descriptor.openai.ToolsH\x0b\x12\x16\n\x0ctop_logprobs\x18\r \x01(\x05H\x0c\x12\x0f\n\x05top_p\x18\x0e \x01(\x01H\r\x12\x0e\n\x04user\x18\x0f \x01(\tH\x0e\x42\x1c\n\x1aoptional_frequency_penaltyB\x15\n\x13optional_logit_biasB\x13\n\x11optional_logprobsB\x15\n\x13optional_max_tokensB\x0c\n\noptional_nB\x1b\n\x19optional_presence_penaltyB\x1a\n\x18optional_response_formatB\x0f\n\roptional_seedB\x0f\n\roptional_stopB\x16\n\x14optional_temperatureB\x16\n\x14optional_tool_choiceB\x10\n\x0eoptional_toolsB\x17\n\x15optional_top_logprobsB\x10\n\x0eoptional_top_pB\x0f\n\roptional_user\"/\n\x05Tools\x12&\n\x05tools\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct\"V\n\nToolChoice\x12\'\n\x04json\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x12\x11\n\x07literal\x18\x02 \x01(\tH\x00\x42\x0c\n\nvalue_type\"m\n\x12OpenAICapabilities\x12\x46\n\x08\x63hat_api\x18\x01 \x01(\x0b\x32\x32.qwak.llmops.model_descriptor.openai.OpenAIChatAPIH\x00\x42\x0f\n\roptional_chat\"z\n\rOpenAIChatAPI\x12Q\n\x0b\x63hat_params\x18\x01 \x01(\x0b\x32:.qwak.llmops.model_descriptor.openai.OpenAIChatModelParamsH\x00\x42\x16\n\x14optional_chat_paramsB.\n*com.qwak.ai.llmops.model_descriptor.openaiP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.model_descriptor.open_ai_descriptor_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*com.qwak.ai.llmops.model_descriptor.openaiP\001'
  _globals['_OPENAIPROVIDERDESCRIPTOR']._serialized_start=117
  _globals['_OPENAIPROVIDERDESCRIPTOR']._serialized_end=219
  _globals['_OPENAIMODELDESCRIPTOR']._serialized_start=221
  _globals['_OPENAIMODELDESCRIPTOR']._serialized_end=341
  _globals['_OPENAICHATMODELPARAMS']._serialized_start=344
  _globals['_OPENAICHATMODELPARAMS']._serialized_end=1159
  _globals['_TOOLS']._serialized_start=1161
  _globals['_TOOLS']._serialized_end=1208
  _globals['_TOOLCHOICE']._serialized_start=1210
  _globals['_TOOLCHOICE']._serialized_end=1296
  _globals['_OPENAICAPABILITIES']._serialized_start=1298
  _globals['_OPENAICAPABILITIES']._serialized_end=1407
  _globals['_OPENAICHATAPI']._serialized_start=1409
  _globals['_OPENAICHATAPI']._serialized_end=1531
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/features_operator/v3/features_operator_async_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.features_operator.v3 import features_operator_pb2 as qwak_dot_features__operator_dot_v3_dot_features__operator__pb2
from _qwak_proto.qwak.feature_store.features import feature_set_pb2 as qwak_dot_feature__store_dot_features_dot_feature__set__pb2
from _qwak_proto.qwak.feature_store.sources import data_source_pb2 as qwak_dot_feature__store_dot_sources_dot_data__source__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?qwak/features_operator/v3/features_operator_async_service.proto\x12\x19qwak.features_operator.v3\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31qwak/features_operator/v3/features_operator.proto\x1a-qwak/feature_store/features/feature_set.proto\x1a,qwak/feature_store/sources/data_source.proto\"\xeb\x01\n\x19ValidateDataSourceRequest\x12\x44\n\x10\x64\x61ta_source_spec\x18\x01 \x01(\x0b\x32*.qwak.feature.store.sources.DataSourceSpec\x12\x13\n\x0bnum_samples\x18\x02 \x01(\x05\x12T\n\x12validation_options\x18\x03 \x01(\x0b\x32\x36.qwak.features_operator.v3.DataSourceValidationOptionsH\x00\x42\x1d\n\x1boptional_validation_options\"\xfe\x01\n\x19ValidateFeatureSetRequest\x12\x45\n\x10\x66\x65\x61ture_set_spec\x18\x01 \x01(\x0b\x32+.qwak.feature.store.features.FeatureSetSpec\x12\x10\n\x08zip_path\x18\x02 \x01(\t\x12\x13\n\x0bnum_samples\x18\x03 \x01(\x05\x12T\n\x12validation_options\x18\x04 \x01(\x0b\x32\x36.qwak.features_operator.v3.FeatureSetValidationOptionsH\x00\x42\x1d\n\x1boptional_validation_options\"(\n\x12ValidationResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\"0\n\x1aGetValidationResultRequest\x12\x12\n\nrequest_id\x18\x01 \x01(\t\"\x9e\x02\n\x1bGetValidationResultResponse\x12P\n\x10success_response\x18\x01 \x01(\x0b\x32\x34.qwak.features_operator.v3.ValidationSuccessResponseH\x00\x12P\n\x10\x66\x61ilure_response\x18\x02 \x01(\x0b\x32\x34.qwak.features_operator.v3.ValidationFailureResponseH\x00\x12S\n\x12not_ready_response\x18\x03 \x01(\x0b\x32\x35.qwak.features_operator.v3.ValidationNotReadyResponseH\x00\x42\x06\n\x04type\"-\n\x17\x43\x61ncelValidationRequest\x12\x12\n\nrequest_id\x18\x01 \x01(\t\"\x1a\n\x18\x43\x61ncelValidationResponse\"\xcb\x01\n\x1b\x46\x65\x61tureSetValidationOptions\x12\x1b\n\x11\x64\x61ta_source_limit\x18\x01 \x01(\x05H\x00\x12O\n\x15validation_time_range\x18\x02 \x01(\x0b\x32..qwak.features_operator.v3.ValidationTimeRangeH\x01\x42\x1c\n\x1aoptional_data_source_limitB \n\x1eoptional_validation_time_range\"\x90\x01\n\x1b\x44\x61taSourceValidationOptions\x12O\n\x15validation_time_range\x18\x01 \x01(\x0b\x32..qwak.features_operator.v3.ValidationTimeRangeH\x00\x42 \n\x1eoptional_validation_time_range\"\xbf\x01\n\x13ValidationTimeRange\x12\x36\n\x10lower_time_bound\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\x36\n\x10upper_time_bound\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01\x42\x1b\n\x19optional_lower_time_boundB\x1b\n\x19optional_upper_time_bound2\x98\x04\n\x1c\x46\x65\x61turesOperatorAsyncService\x12y\n\x12ValidateDataSource\x12\x34.qwak.features_operator.v3.ValidateDataSourceRequest\x1a-.qwak.features_operator.v3.ValidationResponse\x12y\n\x12ValidateFeatureSet\x12\x34.qwak.features_operator.v3.ValidateFeatureSetRequest\x1a-.qwak.features_operator.v3.ValidationResponse\x12\x84\x01\n\x13GetValidationResult\x12\x35.qwak.features_operator.v3.GetValidationResultRequest\x1a\x36.qwak.features_operator.v3.GetValidationResultResponse\x12{\n\x10\x43\x61ncelValidation\x12\x32.qwak.features_operator.v3.CancelValidationRequest\x1a\x33.qwak.features_operator.v3.CancelValidationResponseB(\n$com.qwak.ai.features.operator.api.v3P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.features_operator.v3.features_operator_async_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$com.qwak.ai.features.operator.api.v3P\001'
  _globals['_VALIDATEDATASOURCEREQUEST']._serialized_start=272
  _globals['_VALIDATEDATASOURCEREQUEST']._serialized_end=507
  _globals['_VALIDATEFEATURESETREQUEST']._serialized_start=510
  _globals['_VALIDATEFEATURESETREQUEST']._serialized_end=764
  _globals['_VALIDATIONRESPONSE']._serialized_start=766
  _globals['_VALIDATIONRESPONSE']._serialized_end=806
  _globals['_GETVALIDATIONRESULTREQUEST']._serialized_start=808
  _globals['_GETVALIDATIONRESULTREQUEST']._serialized_end=856
  _globals['_GETVALIDATIONRESULTRESPONSE']._serialized_start=859
  _globals['_GETVALIDATIONRESULTRESPONSE']._serialized_end=1145
  _globals['_CANCELVALIDATIONREQUEST']._serialized_start=1147
  _globals['_CANCELVALIDATIONREQUEST']._serialized_end=1192
  _globals['_CANCELVALIDATIONRESPONSE']._serialized_start=1194
  _globals['_CANCELVALIDATIONRESPONSE']._serialized_end=1220
  _globals['_FEATURESETVALIDATIONOPTIONS']._serialized_start=1223
  _globals['_FEATURESETVALIDATIONOPTIONS']._serialized_end=1426
  _globals['_DATASOURCEVALIDATIONOPTIONS']._serialized_start=1429
  _globals['_DATASOURCEVALIDATIONOPTIONS']._serialized_end=1573
  _globals['_VALIDATIONTIMERANGE']._serialized_start=1576
  _globals['_VALIDATIONTIMERANGE']._serialized_end=1767
  _globals['_FEATURESOPERATORASYNCSERVICE']._serialized_start=1770
  _globals['_FEATURESOPERATORASYNCSERVICE']._serialized_end=2306
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/projects/jfrog_project_spec.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&qwak/projects/jfrog_project_spec.proto\x12\x18qwak.projects.management\"S\n\x18ModelRepositoryJFrogSpec\x12\x1b\n\x11jfrog_project_key\x18\x01 \x01(\tH\x00\x42\x1a\n\x18jfrog_project_identifierB\'\n#com.qwak.ai.management.projects.apiP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.projects.jfrog_project_spec_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.qwak.ai.management.projects.apiP\001'
  _globals['_MODELREPOSITORYJFROGSPEC']._serialized_start=68
  _globals['_MODELREPOSITORYJFROGSPEC']._serialized_end=151
# @@protoc_insertion_point(module_scope)
